@@ -1,7 +1,13 @@
-﻿#ifndef JOBTYPELISTVIEW_H
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
+#ifndef JOBTYPELISTVIEW_H
 #define JOBTYPELISTVIEW_H
 
 #include "scheduledatamanage.h"
+#include "daccount.h"
+#include "accountitem.h"
 
 #include <DListView>
 #include <DIconButton>
@@ -9,9 +15,11 @@
 #include <QWidget>
 #include <QList>
 #include <QTableView>
+#include <DDialog>
 
 DWIDGET_USE_NAMESPACE
 
+class JobTypeListViewStyle;
 class JobTypeListView : public QTableView
 {
     Q_OBJECT
@@ -23,15 +31,19 @@ public:
      * @brief canAdd 是否可以继续新增类型
      */
     bool canAdd();
+
+    void setItemEnabled(bool b);
+
 protected:
     bool viewportEvent(QEvent *event) override;
+
 private:
     void initUI();//初始化
     /**
      * @brief addJobTypeItem 添加item
      * @return 返回item的高度
      */
-    int addJobTypeItem(const JobTypeInfo &info);//新增一行【日程类型】数据
+    int addJobTypeItem(const DScheduleType &info); //新增一行【日程类型】数据
 
 signals:
     /**
@@ -41,11 +53,22 @@ signals:
 public slots:
     void slotUpdateJobType();
     void slotDeleteJobType();
+    void slotAddScheduleType();
+    // 导入ics文件
+    void slotImportScheduleType();
+    // 导出ics文件
+    void slotExportScheduleType();
     bool updateJobType();
+    void updateCalendarAccount(QString account_id);
 
 private:
     QStandardItemModel *m_modelJobType {nullptr};
     int m_iIndexCurrentHover = -1;
+
+    friend JobTypeListViewStyle;
+
+    QString m_account_id;
+    DDialog *m_waitDialog = nullptr;
 };
 
 class JobTypeListViewStyle : public DStyledItemDelegate
