@@ -1,21 +1,7 @@
-/*
- * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     kirigaya <kirigaya@mkacg.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "scheduleview.h"
 #include "alldayeventview.h"
 #include "graphicsview.h"
@@ -34,6 +20,7 @@
 #include <QShortcut>
 #include <QVBoxLayout>
 #include <QApplication>
+#include <QDesktopWidget>
 
 DGUI_USE_NAMESPACE
 
@@ -43,7 +30,7 @@ CScheduleView::CScheduleView(QWidget *parent, ScheduleViewPos viewType)
     : DFrame(parent)
     , m_viewPos(viewType)
     , m_touchGesture(this)
-    , m_timeFormat(CalendarManager::getInstance()->getCalendarDateDataManage()->getTimeFormat())
+    , m_timeFormat(CalendarManager::getInstance()->getTimeFormat())
 {
     initUI();
     initConnection();
@@ -124,9 +111,9 @@ void CScheduleView::setTime(QTime time)
     m_graphicsView->setTime(time);
 }
 
-void CScheduleView::setSelectSchedule(const ScheduleDataInfo &scheduleInfo)
+void CScheduleView::setSelectSchedule(const DSchedule::Ptr &scheduleInfo)
 {
-    if (scheduleInfo.getAllDay()) {
+    if (scheduleInfo->allDay()) {
         m_alldaylist->setSelectSearchSchedule(scheduleInfo);
     } else {
         m_graphicsView->setSelectSearchSchedule(scheduleInfo);
@@ -153,7 +140,7 @@ void CScheduleView::setCurrentDate(const QDateTime &currentDate)
  * @brief CScheduleView::setShowScheduleInfo        设置显示日程
  * @param scheduleInfo
  */
-void CScheduleView::setShowScheduleInfo(const QMap<QDate, QVector<ScheduleDataInfo> > &scheduleInfo)
+void CScheduleView::setShowScheduleInfo(const QMap<QDate, DSchedule::List> &scheduleInfo)
 {
     m_showSchedule = scheduleInfo;
     updateSchedule();
@@ -216,7 +203,7 @@ void CScheduleView::paintEvent(QPaintEvent *event)
                 painter.drawText(
                     QRect((m_leftMargin - hourTextWidth) / 2 - 5, m_topMargin - 8 + m_vPos[i],
                           hourTextWidth, hourTextHeight),
-                    Qt::AlignCenter, QTime(m_vHours[i], 0).toString("AP h 时"));
+                    Qt::AlignCenter, QTime(m_vHours[i], 0).toString(m_timeFormat.contains("AP") ? "AP h 时" : m_timeFormat));
             }
             painter.restore();
         } else {
@@ -239,7 +226,7 @@ void CScheduleView::paintEvent(QPaintEvent *event)
                 painter.drawText(
                     QRect((m_leftMargin - hourTextWidth) / 2 - 5, m_topMargin - 8 + m_vPos[i],
                           hourTextWidth, hourTextHeight),
-                    Qt::AlignCenter, QTime(m_vHours[i], 0).toString("AP h 时"));
+                    Qt::AlignCenter, QTime(m_vHours[i], 0).toString(m_timeFormat.contains("AP") ? "AP h 时" : m_timeFormat));
             }
             painter.restore();
 
@@ -247,9 +234,9 @@ void CScheduleView::paintEvent(QPaintEvent *event)
                 painter.save();
                 painter.setFont(font);
                 painter.setPen(m_currenttimecolor);
-                QString str = QTime::currentTime().toString("AP " + m_timeFormat);
+                QString str = QTime::currentTime().toString(m_timeFormat);
                 painter.drawText(QRect((m_leftMargin - hourTextWidth) / 2 - 5,
-                                       m_topMargin - 8 + m_vPos[m_vPos.count() - 1], hourTextWidth,
+                                       m_topMargin - 8 + m_vPos[m_vPos.count() - 1], hourTextWidth + 1,
                                        hourTextHeight),
                                  Qt::AlignCenter, str);
                 painter.restore();
@@ -342,6 +329,13 @@ void CScheduleView::paintEvent(QPaintEvent *event)
         painter.setPen(Qt::NoPen);
         painter.setBrush(m_outerBorderColor);
         painter.drawRect(QRectF(this->width() - 1, 0, this->width(), this->height()));
+        //绘制个三角遮住左上角圆角
+        QPainterPath path;
+        path.moveTo(0,0);
+        path.lineTo(m_radius, 0);
+        path.lineTo(0, m_radius);
+        path.lineTo(0, 0);
+        painter.fillPath(path, palette().color(backgroundRole()));
     }
 }
 
@@ -366,7 +360,7 @@ void CScheduleView::resizeEvent(QResizeEvent *event)
 
 void CScheduleView::wheelEvent(QWheelEvent *e)
 {
-    if (e->orientation() == Qt::Orientation::Horizontal) {
+    if (e->angleDelta().x() != 0) {
         emit signalAngleDelta(e->angleDelta().x());
     }
 }
@@ -480,14 +474,15 @@ void CScheduleView::slotCurrentScheduleDate(QDate date)
     emit signalsCurrentScheduleDate(date);
 }
 
-void CScheduleView::slotScheduleShow(const bool isShow, const ScheduleDataInfo &out)
+void CScheduleView::slotScheduleShow(const bool isShow, const DSchedule::Ptr &out)
 {
     if (isShow) {
         QVariant variant;
         CalendarGlobalEnv::getGlobalEnv()->getValueByKey(DDECalendar::CursorPointKey, variant);
         QPoint pos22 = variant.value<QPoint>();
+        //根据日程类型获取颜色
         CSchedulesColor gdColor = CScheduleDataManage::getScheduleDataManage()->getScheduleColorByType(
-                                      out.getType());
+            out->scheduleTypeID());
         QDesktopWidget *w = QApplication::desktop();
         m_ScheduleRemindWidget->setData(out, gdColor);
 
@@ -537,17 +532,19 @@ void CScheduleView::updateSchedule()
 {
     //获取一个月的日程信息
     m_graphicsView->clearSchedule();
-    QVector<ScheduleDataInfo> allInfo;
-    QVector<ScheduleDataInfo> nonAllInfo;
+    DSchedule::List allInfo;
+    DSchedule::List nonAllInfo;
 
-    QMap<QDate, QVector<ScheduleDataInfo> >::const_iterator _iterator = m_showSchedule.constBegin();
+    QMap<QDate, DSchedule::List>::const_iterator _iterator = m_showSchedule.constBegin();
     for (; _iterator != m_showSchedule.constEnd(); ++_iterator) {
         for (int i = 0; i < _iterator->size(); ++i) {
-            if (_iterator.value().at(i).getAllDay()) {
+            if (_iterator.value().at(i)->allDay()) {
+                //过滤
                 if (!allInfo.contains(_iterator.value().at(i))) {
                     allInfo.append(_iterator.value().at(i));
                 }
             } else {
+                //过滤
                 if (!nonAllInfo.contains(_iterator.value().at(i))) {
                     nonAllInfo.append(_iterator.value().at(i));
                 }
