@@ -1,21 +1,7 @@
-/*
- * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     kirigaya <kirigaya@mkacg.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "scheduledlg.h"
 #include "schedulectrldlg.h"
 #include "scheduledatamanage.h"
@@ -24,8 +10,11 @@
 #include "cscheduleoperation.h"
 #include "cdynamicicon.h"
 #include "configsettings.h"
+#include "accountmanager.h"
+#include "units.h"
+#include "commondef.h"
+
 
-#include <DHiDPIHelper>
 #include <DFontSizeManager>
 #include <DRadioButton>
 #include <DLabel>
@@ -37,9 +26,9 @@
 #include <QKeyEvent>
 #include <QPainter>
 #include <QBitmap>
+#include <QTimer>
 
 const int  dialog_width = 468;      //对话框宽度
-
 DGUI_USE_NAMESPACE
 CScheduleDlg::CScheduleDlg(int type, QWidget *parent, const bool isAllDay)
     : DCalendarDDialog(parent)
@@ -50,7 +39,7 @@ CScheduleDlg::CScheduleDlg(int type, QWidget *parent, const bool isAllDay)
     initUI();
     initConnection();
     setTabFouseOrder();
-    initColor();
+    slotAccountUpdate();
 
     if (type == 1) {
         m_titleLabel->setText(tr("New Event"));
@@ -68,7 +57,11 @@ CScheduleDlg::CScheduleDlg(int type, QWidget *parent, const bool isAllDay)
     } else {
         m_titleLabel->setText(tr("Edit Event"));
     }
-    setFixedSize(dialog_width, 524);
+    setFixedSize(dialog_width, 561);
+    if (!gAccountManager->getIsSupportUid()) {
+        setFixedSize(dialog_width, 561 - 36);
+    }
+
     //焦点设置到输入框
     m_textEdit->setFocus();
 }
@@ -77,36 +70,57 @@ CScheduleDlg::~CScheduleDlg()
 {
 }
 
-void CScheduleDlg::setData(const ScheduleDataInfo &info)
+void CScheduleDlg::setData(const DSchedule::Ptr &info)
 {
-    m_ScheduleDataInfo = info;
-    m_typeComBox->setCurrentJobTypeNo(info.getType());
+    m_scheduleDataInfo = info;
+
     if (m_type == 1) {
         //如果为新建则设置为提示信息
-        m_textEdit->setPlaceholderText(info.getTitleName());
+        m_textEdit->setPlaceholderText(info->summary());
+        m_accountItem = gAccountManager->getLocalAccountItem();
     } else {
         //如果为编辑则显示
-        m_textEdit->setPlainText(info.getTitleName());
+        m_textEdit->setPlainText(info->summary());
         //光标移动到文末
         m_textEdit->moveCursor(QTextCursor::End, QTextCursor::MoveAnchor);
+        m_accountItem = gAccountManager->getAccountItemByScheduleTypeId(info->scheduleTypeID());
+        //编辑状态下帐户不可切换，因此将帐户选择框置灰
+        m_accountComBox->setEnabled(false);
     }
 
-    m_beginDateEdit->setDate(info.getBeginDateTime().date());
-    m_beginTimeEdit->setTime(info.getBeginDateTime().time());
-    m_endDateEdit->setDate(info.getEndDateTime().date());
-    m_endTimeEdit->setTime(info.getEndDateTime().time());
-    m_allDayCheckbox->setChecked(info.getAllDay());
-    m_endRepeatDate->setMinimumDate(info.getBeginDateTime().date());
+    if (nullptr != m_accountItem) {
+        //更新帐户下拉框和类型选择框
+        m_accountComBox->setCurrentText(m_accountItem->getAccount()->accountName());
+        m_typeComBox->updateJobType(m_accountItem);
+    } else {
+        m_accountItem = gAccountManager->getLocalAccountItem();
+    }
 
-    m_currentDate = info.getBeginDateTime();
-    m_EndDate = info.getEndDateTime();
+    if (m_scheduleDataInfo) {
+        m_typeComBox->setCurrentJobTypeNo(m_scheduleDataInfo->scheduleTypeID());
+    }
+
+    m_beginDateEdit->setDate(info->dtStart().date());
+    m_beginTimeEdit->setTime(info->dtStart().time());
+    m_endDateEdit->setDate(info->dtEnd().date());
+    m_endTimeEdit->setTime(info->dtEnd().time());
+    m_allDayCheckbox->setChecked(info->allDay());
+    m_endRepeatDate->setMinimumDate(info->dtStart().date());
+
+    m_currentDate = info->dtStart();
+    m_EndDate = info->dtEnd();
+    if (info->lunnar()) {
+        m_lunarRadioBtn->click();
+    } else {
+        m_solarRadioBtn->click();
+    }
 
     updateEndTimeListAndTimeDiff(m_currentDate, m_EndDate);
-    slotallDayStateChanged(info.getAllDay());
+    slotallDayStateChanged(info->allDay());
     //根据是否为农历更新重复选项
-    updateRepeatCombox(info.getIsLunar());
+    updateRepeatCombox(info->lunnar());
     initRmindRpeatUI();
-    setShowState(info.getIsLunar());
+    setShowState(info->lunnar());
 }
 
 void CScheduleDlg::setDate(const QDateTime &date)
@@ -152,159 +166,164 @@ void CScheduleDlg::setAllDay(bool flag)
  */
 bool CScheduleDlg::clickOkBtn()
 {
-    ScheduleDataInfo _newSchedule = m_ScheduleDataInfo;
+    return selectScheduleType();
+}
+
+/**
+ * @brief CScheduleDlg::selectScheduleType
+ * 选择日程类型
+ * @return 是否可关闭弹窗
+ */
+bool CScheduleDlg::selectScheduleType()
+{
+    //编辑状态，需要创建日程
+    if (m_typeComBox->isEditable()) {
+        DScheduleType::Ptr type;
+        type.reset(new DScheduleType());
+        type->setTypeID("0");
+        type->setDisplayName(m_typeComBox->lineEdit()->text());
+        type->setTypeColor(*m_colorSeletorWideget->getSelectedColorInfo().data());
+        if (m_bCanCreateType) {
+            m_bCanCreateType = false;
+            //创建日程类型，等待回调
+            m_accountItem->createJobType(type, [&](CallMessge call) {
+                if (call.code == 0) {
+                    //返回值为日程类型id
+                    createSchedule(call.msg.toString());
+                } else {
+                    m_bCanCreateType = true;
+                }
+                //关闭本弹窗
+                this->close();
+            });
+        }
+
+    } else if (m_typeComBox->currentIndex() >= 0) {
+        //选择已有日程，直接创建日程
+        return createSchedule(m_typeComBox->getCurrentJobTypeNo());
+    }
+    return false;
+}
+
+/**
+ * @brief CScheduleDlg::createSchedule
+ * 创建日程
+ * @param scheduleTypeId 日程所属日程类型的id
+ * @return
+ */
+bool CScheduleDlg::createSchedule(const QString &scheduleTypeId)
+{
+    //创建新的日程实例
+    DSchedule::Ptr schedule;
+    schedule.reset(new DSchedule());
+    //设置所属日程类型id
+    schedule->setScheduleTypeID(scheduleTypeId);
+
     QDateTime beginDateTime, endDateTime;
     beginDateTime.setDate(m_beginDateEdit->date());
     beginDateTime.setTime(m_beginTimeEdit->getTime());
     endDateTime.setDate(m_endDateEdit->date());
     endDateTime.setTime(m_endTimeEdit->getTime());
 
+    schedule->setDtStart(beginDateTime);
+    schedule->setDtEnd(endDateTime);
+
     //设置是否为农历日程
     switch (m_calendarCategoryRadioGroup->checkedId()) {
     case 1:
         //农历日程
-        _newSchedule.setIsLunar(true);
+        schedule->setLunnar(true);
         break;
     default:
         //公历日程
-        _newSchedule.setIsLunar(false);
+        schedule->setLunnar(false);
         break;
     }
 
     if (m_textEdit->toPlainText().isEmpty()) {
-        _newSchedule.setTitleName(m_textEdit->placeholderText());
+        schedule->setSummary(m_textEdit->placeholderText());
     } else {
-        _newSchedule.setTitleName(m_textEdit->toPlainText());
+        schedule->setSummary(m_textEdit->toPlainText().trimmed());
     }
 
-    if (_newSchedule.getTitleName().isEmpty()) {
+    if (schedule->summary().isEmpty()) {
         return false;
     }
-    //如果类型选项不为负数则设置日程类型
-    if (m_typeComBox->isEditable()) {
-        JobTypeInfo jobType(0, m_typeComBox->lineEdit()->text(), m_colorSeletorWideget->getSelectedColorInfo());
-        //创建日程类型
-        if (CScheduleOperation().createJobType(jobType)) {
-            _newSchedule.setType(jobType.getJobTypeNo());
-        }
-    } else if (m_typeComBox->currentIndex() >= 0)
-        _newSchedule.setType(m_typeComBox->getCurrentJobTypeNo());
 
     if (beginDateTime > endDateTime) {
         DCalendarDDialog *prompt = new DCalendarDDialog(this);
-        prompt->setIcon(QIcon(":/resources/icon/warning.svg"));
+        prompt->setIcon(QIcon(":/icons/deepin/builtin/icons/dde_calendar_warning.svg"));
         prompt->setMessage(tr("End time must be greater than start time"));
         prompt->addButton(tr("OK", "button"), true, DDialog::ButtonNormal);
         prompt->exec();
         return false;
     }
-    if (m_type == 1)
-        _newSchedule.setID(0) ;
-    _newSchedule.setAllDay(m_allDayCheckbox->isChecked());
+    schedule->setAllDay(m_allDayCheckbox->isChecked());
 
-    RemindData _remindData;
-    if (_newSchedule.getAllDay()) {
-        _remindData.setRemindTime(QTime(9, 0));
-        switch (m_rmindCombox->currentIndex()) {
-        case 1:
-            _remindData.setRemindNum(DDECalendar::OnStartDay);
-            break;
-        case 2:
-            _remindData.setRemindNum(DDECalendar::OneDayBeforeWithDay);
-            break;
-        case 3:
-            _remindData.setRemindNum(DDECalendar::TwoDayBeforeWithDay);
-            break;
-        case 4:
-            _remindData.setRemindNum(DDECalendar::OneWeekBeforeWithDay);
-            break;
-        default:
-            break;
+    //设置提醒规则
+    DSchedule::AlarmType alarmType;
+    if (schedule->allDay()) {
+        alarmType = static_cast<DSchedule::AlarmType>(m_rmindCombox->currentIndex() + 8);
+    } else {
+        alarmType = static_cast<DSchedule::AlarmType>(m_rmindCombox->currentIndex());
+    }
+    schedule->setAlarmType(alarmType);
+
+    //设置重复规则
+    DSchedule::RRuleType rruleType;
+    if (schedule->lunnar()) {
+        //0:从不 1:每月 2:每年
+        if (m_beginrepeatCombox->currentIndex() == 1) {
+            rruleType = DSchedule::RRule_Month;
+        } else if (m_beginrepeatCombox->currentIndex() == 2) {
+            rruleType = DSchedule::RRule_Year;
+        } else {
+            rruleType = DSchedule::RRule_None;
         }
     } else {
-        switch (m_rmindCombox->currentIndex()) {
-        case 1:
-            _remindData.setRemindNum(DDECalendar::AtTimeOfEvent);
-            break;
-        case 2:
-            _remindData.setRemindNum(DDECalendar::FifteenMinutesBefore);
-            break;
-        case 3:
-            _remindData.setRemindNum(DDECalendar::ThirtyMinutesBefore);
-            break;
-        case 4:
-            _remindData.setRemindNum(DDECalendar::OneHourBefore);
-            break;
-        case 5:
-            _remindData.setRemindNum(DDECalendar::OneDayBeforeWithMinutes);
-            break;
-        case 6:
-            _remindData.setRemindNum(DDECalendar::TwoDayBeforeWithMinutes);
-            break;
-        case 7:
-            _remindData.setRemindNum(DDECalendar::OneWeekBeforeWithMinutes);
-            break;
-        default:
-            break;
-        }
+        //0:从不 1:每天 2:每个工作日 3:每周 4:每月 5:每年
+        rruleType = static_cast<DSchedule::RRuleType>(m_beginrepeatCombox->currentIndex());
     }
-    _newSchedule.setRemindData(_remindData);
-
-    RepetitionRule _repetitionRule;
-    //根据是否为农历日程，设置对应的重复规则
-    RepetitionRule::RRuleID ruleID;
-    if (_newSchedule.getIsLunar()) {
-        switch (m_beginrepeatCombox->currentIndex()) {
-        case 1:
-            //每月
-            ruleID = RepetitionRule::RRule_EVEMONTH;
-            break;
-        case 2: {
-            //每年
-            ruleID = RepetitionRule::RRule_EVEYEAR;
-        } break;
-        default:
-            //默认不重复
-            ruleID = RepetitionRule::RRule_NONE;
-            break;
+    schedule->setRRuleType(rruleType);
+    if (m_endrepeatCombox->currentIndex() == 1) {
+        //结束与次数
+        if (m_endrepeattimes->text().isEmpty()) {
+            return false;
         }
+        schedule->recurrence()->setDuration(m_endrepeattimes->text().toInt() + 1);
 
+    } else if (m_endrepeatCombox->currentIndex() == 2) {
+        //结束与日期
+        QDateTime endrpeattime = beginDateTime;
+        endrpeattime.setDate(m_endRepeatDate->date());
+
+        if (beginDateTime > endrpeattime) {
+            return false;
+        }
+        schedule->recurrence()->setDuration(0);
+        schedule->recurrence()->setEndDateTime(endrpeattime);
     } else {
-        ruleID = static_cast<RepetitionRule::RRuleID>(m_beginrepeatCombox->currentIndex());
+        //永不
+        schedule->recurrence()->setDuration(-1);
     }
-    _repetitionRule.setRuleId(ruleID);
-    if (_repetitionRule.getRuleId() > 0) {
-        _repetitionRule.setRuleType(static_cast<RepetitionRule::RRuleEndType>
-                                    (m_endrepeatCombox->currentIndex()));
-        if (m_endrepeatCombox->currentIndex() == 1) {
-            if (m_endrepeattimes->text().isEmpty()) {
-                return false;
-            }
-            _repetitionRule.setEndCount(m_endrepeattimes->text().toInt());
-        } else if (m_endrepeatCombox->currentIndex() == 2) {
-            QDateTime endrpeattime = beginDateTime;
-            endrpeattime.setDate(m_endRepeatDate->date());
 
-            if (beginDateTime > endrpeattime) {
-                return false;
-            }
-            _repetitionRule.setEndDate(endrpeattime);
-        }
-    }
-    _newSchedule.setRepetitionRule(_repetitionRule);
-    _newSchedule.setBeginDateTime(beginDateTime);
-    _newSchedule.setEndDateTime(endDateTime);
-    CScheduleOperation _scheduleOperation(this);
+    CScheduleOperation _scheduleOperation(m_accountItem, this);
 
+    bool res = false;
     if (m_type == 1) {
         //创建日程
-        _scheduleOperation.createSchedule(_newSchedule);
+        schedule->setUid("0");
+        res = _scheduleOperation.createSchedule(schedule);
 
     } else if (m_type == 0) {
-        //修改日程,根据返回的参数判断是否关闭对话框
-        return _scheduleOperation.changeSchedule(_newSchedule, m_ScheduleDataInfo);
+        schedule->setUid(m_scheduleDataInfo->uid());
+        //如果有重复规则则将原来数据的忽略列表添加进来
+        if (schedule->recurs() && m_scheduleDataInfo->recurs()) {
+            schedule->recurrence()->setExDateTimes(m_scheduleDataInfo->recurrence()->exDateTimes());
+        }
+        res = _scheduleOperation.changeSchedule(schedule, m_scheduleDataInfo);
     }
-    return true;
+    return res;
 }
 
 void CScheduleDlg::updateEndTimeListAndTimeDiff(const QDateTime &begin, const QDateTime &end)
@@ -386,7 +405,7 @@ void CScheduleDlg::slotBtClick(int buttonIndex, const QString &buttonName)
         //确定
         //自动化测试会出现短时间内按钮click2次的情况。添加第一次触发后将保存按钮置灰的设置。
         //若保存按钮不启用则不处理
-        if (getButton(1)->isEnabled()) {
+        if (getButton(1)->isEnabled()  && !this->isHidden()) {
             m_setAccept = clickOkBtn();
             //若新建或编辑成功则将保存按钮置灰
             getButton(1)->setEnabled(!m_setAccept);
@@ -429,7 +448,9 @@ void CScheduleDlg::slotTextChange()
         return;
     }
 
-    m_context = m_textEdit->toPlainText();
+    setOkBtnEnabled();
+
+    m_context = m_textEdit->toPlainText().trimmed();
 }
 
 void CScheduleDlg::slotendrepeatTextchange()
@@ -465,14 +486,20 @@ void CScheduleDlg::slotallDayStateChanged(int state)
         m_rmindCombox->addItem(tr("1 day before"));
         m_rmindCombox->addItem(tr("2 days before"));
         m_rmindCombox->addItem(tr("1 week before"));
+        m_rmindCombox->setCurrentIndex(2);
         m_beginTimeEdit->setVisible(true);
         m_endTimeEdit->setVisible(true);
 
         if (m_type == 0) {
-            m_beginDateEdit->setDate(m_ScheduleDataInfo.getBeginDateTime().date());
-            m_beginTimeEdit->setTime(m_ScheduleDataInfo.getBeginDateTime().time());
-            m_endDateEdit->setDate(m_ScheduleDataInfo.getEndDateTime().date());
-            m_endTimeEdit->setTime(m_ScheduleDataInfo.getEndDateTime().time());
+            m_beginDateEdit->setDate(m_scheduleDataInfo->dtStart().date());
+            m_beginTimeEdit->setTime(m_scheduleDataInfo->dtStart().time());
+            m_endDateEdit->setDate(m_scheduleDataInfo->dtEnd().date());
+            m_endTimeEdit->setTime(m_scheduleDataInfo->dtEnd().time());
+            if (m_scheduleDataInfo->dtStart().time() == m_scheduleDataInfo->dtEnd().time()
+                    && m_scheduleDataInfo->dtEnd().time().toString() == "00:00:00") {
+                m_endTimeEdit->setTime(QTime(23, 59, 59));
+            }
+
         } else {
             m_beginDateEdit->setDate(m_currentDate.date());
             m_beginTimeEdit->setTime(m_currentDate.time());
@@ -485,20 +512,20 @@ void CScheduleDlg::slotallDayStateChanged(int state)
         m_rmindCombox->addItem(tr("1 day before"));
         m_rmindCombox->addItem(tr("2 days before"));
         m_rmindCombox->addItem(tr("1 week before"));
+        m_rmindCombox->setCurrentIndex(2);
         m_beginTimeEdit->setVisible(false);
         m_endTimeEdit->setVisible(false);
 
         if (m_type == 0) {
-            m_beginDateEdit->setDate(m_ScheduleDataInfo.getBeginDateTime().date());
+            m_beginDateEdit->setDate(m_scheduleDataInfo->dtStart().date());
             m_beginTimeEdit->setTime(QTime(0, 0));
-            m_endDateEdit->setDate(m_ScheduleDataInfo.getEndDateTime().date());
+            m_endDateEdit->setDate(m_scheduleDataInfo->dtEnd().date());
             m_endTimeEdit->setTime(QTime(23, 59));
         } else {
             m_beginDateEdit->setDate(m_currentDate.date());
             m_endDateEdit->setDate(m_EndDate.date());
             m_beginTimeEdit->setTime(QTime(0, 0));
             m_endTimeEdit->setTime(QTime(23, 59));
-            m_rmindCombox->setCurrentIndex(2);
         }
     }
 }
@@ -510,6 +537,9 @@ void CScheduleDlg::slotbRpeatactivated(int index)
     } else {
         m_endrepeatWidget->setVisible(false);
     }
+    //不论重复日程选哪种模式，结束重复都是从不
+    m_endrepeatCombox->setCurrentIndex(0);
+    sloteRpeatactivated(0);
     setOkBtnEnabled();
     resize();
 }
@@ -531,6 +561,7 @@ void CScheduleDlg::sloteRpeatactivated(int index)
     } else {
         m_endrepeattimesWidget->setVisible(false);
         m_endRepeatDate->setVisible(true);
+        m_endRepeatDate->setEditCursorPos(0);
     }
     setOkBtnEnabled();
 }
@@ -544,6 +575,33 @@ void CScheduleDlg::slotJobComboBoxEditingFinished()
     }
 }
 
+void CScheduleDlg::slotAccoutBoxActivated(const QString &text)
+{
+    m_accountItem = gAccountManager->getAccountItemByAccountName(text);
+    m_typeComBox->updateJobType(m_accountItem);
+    resetColor(m_accountItem);
+    getButtons()[1]->setEnabled(true);
+    //将焦点转移到类型选择框上
+    m_typeComBox->setFocus();
+    setShowState(m_lunarRadioBtn->isChecked());
+}
+
+void CScheduleDlg::signalLogout(DAccount::Type type)
+{
+    if (DAccount::Account_UnionID == type && gUosAccountItem == m_accountItem) {
+        if (m_type) {
+            //TODO：弹窗提示？
+            qCInfo(ClientLogger) << m_accountComBox->currentText() << "帐户已退出";
+            getButtons()[1]->setEnabled(false);
+            m_accountItem.reset(nullptr);
+        } else {
+            m_accountComBox->setEnabled(true);
+            m_type = 1;
+            m_titleLabel->setText(tr("New Event"));
+        }
+    }
+}
+
 void CScheduleDlg::slotTypeRpeatactivated(int index)
 {
     Q_UNUSED(index);
@@ -609,10 +667,6 @@ void CScheduleDlg::slotTypeEditTextChanged(const QString &text)
         //名称为全空格，返回
         m_typeComBox->showAlertMessage(tr("The name can not only contain whitespaces"));
         m_typeComBox->setAlert(true);
-    } else if (JobTypeInfoManager::instance()->isJobTypeNameUsed(tStitlename)) {
-        //重名，返回
-        m_typeComBox->showAlertMessage(tr("The name already exists"));
-        m_typeComBox->setAlert(true);
     } else {
         //如果日程类型编辑框存在焦点（没有编辑结束）且有警告则取消警告和提示信息
         if (m_typeComBox->hasFocus() && m_typeComBox->isAlert()) {
@@ -752,6 +806,33 @@ void CScheduleDlg::initUI()
     QVBoxLayout *maintlayout = new QVBoxLayout;
     maintlayout->setMargin(0);
     maintlayout->setSpacing(10);
+    //帐户
+    {
+        QHBoxLayout *hlayout = new QHBoxLayout;
+        hlayout->setSpacing(0);
+        hlayout->setMargin(0);
+
+        DLabel *aLabel = new DLabel(tr("Calendar account:"));
+        aLabel->setToolTip(tr("Calendar account"));
+        DFontSizeManager::instance()->bind(aLabel, DFontSizeManager::T6);
+        aLabel->setElideMode(Qt::ElideRight);
+        aLabel->setFont(mlabelF);
+        aLabel->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
+        aLabel->setFixedSize(label_Fixed_Width, item_Fixed_Height);
+
+        m_accountComBox = new DComboBox(this);
+        m_accountComBox->setFixedSize(350, item_Fixed_Height);
+        hlayout->addWidget(aLabel);
+        hlayout->addWidget(m_accountComBox);
+        QWidget *widget = new QWidget;
+        widget->setLayout(hlayout);
+        widget->setFixedHeight(item_Fixed_Height);
+        maintlayout->addWidget(widget);
+        if (!gAccountManager->getIsSupportUid()) {
+            widget->hide();
+        }
+    }
+
     //类型
     {
         //使用网格布局
@@ -774,7 +855,6 @@ void CScheduleDlg::initUI()
         m_typeComBox->setObjectName("ScheduleTypeCombobox");
         m_typeComBox->setAccessibleName("ScheduleTypeCombobox");
         m_typeComBox->setFixedSize(350, item_Fixed_Height);
-        initJobTypeComboBox();//todo
 
         m_colorSeletorWideget = new ColorSeletorWidget();
         m_colorSeletorWideget->hide();
@@ -783,8 +863,10 @@ void CScheduleDlg::initUI()
         typelayout->addWidget(m_typeComBox, 0, 1);
         typelayout->addWidget(m_colorSeletorWideget, 1, 1);
         //添加垂直间隔
-        typelayout->setVerticalSpacing(5);
-        maintlayout->addLayout(typelayout);
+        typelayout->setVerticalSpacing(10);
+        QWidget *widget = new QWidget;
+        widget->setLayout(typelayout);
+        maintlayout->addWidget(widget);
     }
 
     //内容
@@ -838,14 +920,18 @@ void CScheduleDlg::initUI()
         m_adllDayLabel->setText(str_allDayLabel);
         m_adllDayLabel->setFont(mlabelF);
         m_adllDayLabel->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
-        m_adllDayLabel->setFixedSize(label_Fixed_Width, item_Fixed_Height);
+        m_adllDayLabel->setFixedSize(label_Fixed_Width, 25);
         m_allDayCheckbox = new DCheckBox(this);
+        m_allDayCheckbox->setFixedHeight(25);
         //设置对象名称和辅助显示名称
         m_allDayCheckbox->setObjectName("AllDayCheckBox");
         m_allDayCheckbox->setAccessibleName("AllDayCheckBox");
         alldayLabellayout->addWidget(m_adllDayLabel);
         alldayLabellayout->addWidget(m_allDayCheckbox);
-        maintlayout->addLayout(alldayLabellayout);
+        QWidget *widget = new QWidget;
+        widget->setLayout(alldayLabellayout);
+        widget->setFixedHeight(25);
+        maintlayout->addWidget(widget);
     }
 
     //时间
@@ -856,12 +942,14 @@ void CScheduleDlg::initUI()
         tLabel->setElideMode(Qt::ElideRight);
         tLabel->setFont(mlabelF);
         tLabel->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
-        tLabel->setFixedSize(DDECalendar::NewScheduleLabelWidth, item_Fixed_Height);
+        tLabel->setFixedSize(DDECalendar::NewScheduleLabelWidth, 25);
 
         m_solarRadioBtn = new DRadioButton(tr("Solar"));
         m_lunarRadioBtn = new DRadioButton(tr("Lunar"));
         m_solarRadioBtn->setMinimumWidth(72);
         m_lunarRadioBtn->setMinimumWidth(72);
+        m_solarRadioBtn->setFixedHeight(25);
+        m_lunarRadioBtn->setFixedHeight(25);
 
         m_calendarCategoryRadioGroup = new QButtonGroup(this);
         m_calendarCategoryRadioGroup->setExclusive(true);
@@ -875,8 +963,13 @@ void CScheduleDlg::initUI()
         tLayout->addWidget(m_solarRadioBtn);
         tLayout->addWidget(m_lunarRadioBtn);
         tLayout->addStretch(1);
+        tLayout->setAlignment(m_solarRadioBtn, Qt::AlignVCenter);
+        tLayout->setAlignment(m_lunarRadioBtn, Qt::AlignVCenter);
 
-        maintlayout->addLayout(tLayout);
+        QWidget *widget = new QWidget;
+        widget->setLayout(tLayout);
+        widget->setFixedHeight(25);
+        maintlayout->addWidget(widget);
     }
 
     //开始时间
@@ -913,7 +1006,11 @@ void CScheduleDlg::initUI()
         beginLabellayout->addSpacing(8);
         beginLabellayout->addWidget(m_beginTimeEdit);
         beginLabellayout->addStretch();
-        maintlayout->addLayout(beginLabellayout);
+
+        QWidget *widget = new QWidget;
+        widget->setLayout(beginLabellayout);
+        widget->setFixedHeight(item_Fixed_Height);
+        maintlayout->addWidget(widget);
     }
 
     //结束时间
@@ -951,7 +1048,10 @@ void CScheduleDlg::initUI()
 
         enQLabellayout->addWidget(m_endTimeEdit);
         enQLabellayout->addStretch();
-        maintlayout->addLayout(enQLabellayout);
+        QWidget *widget = new QWidget;
+        widget->setLayout(enQLabellayout);
+        widget->setFixedHeight(item_Fixed_Height);
+        maintlayout->addWidget(widget);
     }
 
     //提醒
@@ -979,7 +1079,10 @@ void CScheduleDlg::initUI()
         rminQLabellayout->addWidget(m_remindSetLabel);
         rminQLabellayout->addWidget(m_rmindCombox);
         rminQLabellayout->addStretch();
-        maintlayout->addLayout(rminQLabellayout);
+        QWidget *widget = new QWidget;
+        widget->setLayout(rminQLabellayout);
+        widget->setFixedHeight(item_Fixed_Height);
+        maintlayout->addWidget(widget);
     }
 
     //重复
@@ -1011,7 +1114,10 @@ void CScheduleDlg::initUI()
         repeatLabellayout->addWidget(m_beginrepeatLabel);
         repeatLabellayout->addWidget(m_beginrepeatCombox);
         repeatLabellayout->addStretch();
-        maintlayout->addLayout(repeatLabellayout);
+        QWidget *widget = new QWidget;
+        widget->setLayout(repeatLabellayout);
+        widget->setFixedHeight(item_Fixed_Height);
+        maintlayout->addWidget(widget);
     }
 
     //结束重复
@@ -1086,11 +1192,14 @@ void CScheduleDlg::initUI()
         endrepeatLabellayout->addWidget(m_endRepeatDate);
         endrepeatLabellayout->addStretch();
         m_endRepeatDate->setVisible(false);
+        //设置最大日期
+        m_endRepeatDate->setMaximumDate(QDate(2100, 12, 31));
         m_endrepeatWidget = new DWidget;
         //设置对象名称和辅助显示名称
         m_endrepeatWidget->setObjectName("EndRepeatDateWidget");
         m_endrepeatWidget->setAccessibleName("EndRepeatDateWidget");
         m_endrepeatWidget->setLayout(endrepeatLabellayout);
+        m_endrepeatWidget->setFixedHeight(item_Fixed_Height);
         maintlayout->addWidget(m_endrepeatWidget);
         m_endrepeatWidget->setVisible(false);
     }
@@ -1128,6 +1237,8 @@ void CScheduleDlg::initConnection()
             &CScheduleDlg::sloteRpeatactivated);
     connect(m_typeComBox, QOverload<int>::of(&QComboBox::activated), this,
             &CScheduleDlg::slotTypeRpeatactivated);
+    connect(m_accountComBox, &QComboBox::textActivated, this,
+            &CScheduleDlg::slotAccoutBoxActivated);
     connect(m_beginDateEdit, &DDateEdit::userDateChanged, this, &CScheduleDlg::slotBDateEidtInfo);
     QShortcut *shortcut = new QShortcut(this);
     shortcut->setKey(QKeySequence(QLatin1String("ESC")));
@@ -1137,10 +1248,32 @@ void CScheduleDlg::initConnection()
             &CScheduleDlg::slotBeginTimeChange);
     connect(m_endTimeEdit, &CTimeEdit::signaleditingFinished, this, &CScheduleDlg::slotEndTimeChange);
     connect(m_endDateEdit, &QDateEdit::userDateChanged, this, &CScheduleDlg::slotEndDateChange);
-    connect(m_calendarCategoryRadioGroup, QOverload<int>::of(&QButtonGroup::buttonClicked), this, &CScheduleDlg::slotRadioBtnClicked);
+    connect(m_calendarCategoryRadioGroup, &QButtonGroup::idClicked, this, &CScheduleDlg::slotRadioBtnClicked);
     connect(m_typeComBox, &JobTypeComboBox::signalAddTypeBtnClicked, this, &CScheduleDlg::slotBtnAddItemClicked);
     connect(m_typeComBox, &JobTypeComboBox::editTextChanged, this, &CScheduleDlg::slotTypeEditTextChanged);
     connect(m_typeComBox, &JobTypeComboBox::editingFinished, this, &CScheduleDlg::slotJobComboBoxEditingFinished);
+    connect(gAccountManager, &AccountManager::signalLogout, this, &CScheduleDlg::signalLogout);
+    connect(gAccountManager, &AccountManager::signalAccountUpdate, this, &CScheduleDlg::slotAccountUpdate);
+    connect(gAccountManager, &AccountManager::signalAccountStateChange, this, &CScheduleDlg::slotAccountStateChange);
+}
+
+void CScheduleDlg::slotAccountUpdate()
+{
+    m_accountComBox->clear();
+    QList<AccountItem::Ptr> accountList = gAccountManager->getAccountList();
+    for (AccountItem::Ptr p : accountList) {
+        m_accountComBox->addItem(p->getAccount()->accountName());
+    }
+    initJobTypeComboBox();
+}
+
+/**
+ * @brief CScheduleDlg::slotAccountStateChange
+ * 帐户状态发生改变，刷新界面显示
+ */
+void CScheduleDlg::slotAccountStateChange()
+{
+    setShowState(m_lunarRadioBtn->isChecked());
 }
 
 void CScheduleDlg::initDateEdit()
@@ -1151,84 +1284,56 @@ void CScheduleDlg::initDateEdit()
     m_endDateEdit->setMaximumDate(QDate(DDECalendar::QueryLatestYear, 12, 31));
     return;
 }
+
 void CScheduleDlg::initJobTypeComboBox()
 {
-    m_typeComBox->updateJobType();
+    m_accountItem = gAccountManager->getAccountItemByAccountName(m_accountComBox->currentText());
+    m_typeComBox->updateJobType(m_accountItem);
+    resetColor(m_accountItem);
 }
 
 void CScheduleDlg::initRmindRpeatUI()
 {
-    if (m_ScheduleDataInfo.getAllDay()) {
-        if (m_ScheduleDataInfo.getRemindData().getRemindNum() > -1) {
-            if (m_ScheduleDataInfo.getRemindData().getRemindNum() == DDECalendar::OnStartDay) {
-                m_rmindCombox->setCurrentIndex(1);
-            } else if (m_ScheduleDataInfo.getRemindData().getRemindNum() == DDECalendar::OneDayBeforeWithDay) {
-                m_rmindCombox->setCurrentIndex(2);
-            } else if (m_ScheduleDataInfo.getRemindData().getRemindNum() == DDECalendar::TwoDayBeforeWithDay) {
-                m_rmindCombox->setCurrentIndex(3);
-            } else if (m_ScheduleDataInfo.getRemindData().getRemindNum() == DDECalendar::OneWeekBeforeWithDay) {
-                m_rmindCombox->setCurrentIndex(4);
-            }
-        } else {
-            m_rmindCombox->setCurrentIndex(0);
-        }
+    //提醒规则
+    if (m_scheduleDataInfo->allDay()) {
+        m_rmindCombox->setCurrentIndex(m_scheduleDataInfo->getAlarmType() - 8);
     } else {
-        if (m_ScheduleDataInfo.getRemindData().getRemindNum() > -1) {
-            if (m_ScheduleDataInfo.getRemindData().getRemindNum() == DDECalendar::AtTimeOfEvent) {
-                m_rmindCombox->setCurrentIndex(1);
-            } else if (m_ScheduleDataInfo.getRemindData().getRemindNum() == DDECalendar::FifteenMinutesBefore) {
-                m_rmindCombox->setCurrentIndex(2);
-            } else if (m_ScheduleDataInfo.getRemindData().getRemindNum() == DDECalendar::ThirtyMinutesBefore) {
-                m_rmindCombox->setCurrentIndex(3);
-            } else if (m_ScheduleDataInfo.getRemindData().getRemindNum() == DDECalendar::OneHourBefore) {
-                m_rmindCombox->setCurrentIndex(4);
-            } else if (m_ScheduleDataInfo.getRemindData().getRemindNum() ==
-                       DDECalendar::OneDayBeforeWithMinutes) {
-                m_rmindCombox->setCurrentIndex(5);
-            } else if (m_ScheduleDataInfo.getRemindData().getRemindNum() ==
-                       DDECalendar::TwoDayBeforeWithMinutes) {
-                m_rmindCombox->setCurrentIndex(6);
-            } else if (m_ScheduleDataInfo.getRemindData().getRemindNum() ==
-                       DDECalendar::OneWeekBeforeWithMinutes) {
-                m_rmindCombox->setCurrentIndex(7);
-            }
-        } else {
-            m_rmindCombox->setCurrentIndex(0);
-        }
+        m_rmindCombox->setCurrentIndex(m_scheduleDataInfo->getAlarmType());
     }
-    slotbRpeatactivated(m_ScheduleDataInfo.getRepetitionRule().getRuleId());
-    RepetitionRule::RRuleID ruleID = m_ScheduleDataInfo.getRepetitionRule().getRuleId();
-    if (m_ScheduleDataInfo.getIsLunar()) {
-        switch (ruleID) {
-        case RepetitionRule::RRule_EVEYEAR:
-            m_beginrepeatCombox->setCurrentIndex(2);
-            break;
-        case RepetitionRule::RRule_EVEMONTH:
+
+    //重复规则
+    if (m_scheduleDataInfo->lunnar()) {
+        //如果为农历
+        switch (m_scheduleDataInfo->getRRuleType()) {
+        case DSchedule::RRule_Month:
             m_beginrepeatCombox->setCurrentIndex(1);
             break;
+        case DSchedule::RRule_Year:
+            m_beginrepeatCombox->setCurrentIndex(2);
+            break;
         default:
             m_beginrepeatCombox->setCurrentIndex(0);
             break;
         }
-    } else {
-        m_beginrepeatCombox->setCurrentIndex(ruleID);
-    }
 
-    if (m_ScheduleDataInfo.getRepetitionRule().getRuleId() != 0) {
-        if (m_ScheduleDataInfo.getRepetitionRule().getRuleType() == 0) {
-            m_endrepeatCombox->setCurrentIndex(0);
-        } else if (m_ScheduleDataInfo.getRepetitionRule().getRuleType() == 1) {
-            m_endrepeatCombox->setCurrentIndex(1);
-            m_endrepeattimes->setText(QString::number(m_ScheduleDataInfo.getRepetitionRule().getEndCount()));
-        } else if (m_ScheduleDataInfo.getRepetitionRule().getRuleType() == 2) {
-            m_endrepeatCombox->setCurrentIndex(2);
-            m_endRepeatDate->setDate(m_ScheduleDataInfo.getRepetitionRule().getEndDate().date());
-        }
-        m_endrepeatWidget->show();
-        sloteRpeatactivated(m_ScheduleDataInfo.getRepetitionRule().getRuleType());
     } else {
-        m_endrepeatWidget->hide();
+        //如果为公历
+        m_beginrepeatCombox->setCurrentIndex(m_scheduleDataInfo->getRRuleType());
     }
+    slotbRpeatactivated(m_beginrepeatCombox->currentIndex());
+    if (m_scheduleDataInfo->recurrence()->duration() < 0) {
+        //永不
+        m_endrepeatCombox->setCurrentIndex(0);
+    } else if (m_scheduleDataInfo->recurrence()->duration() == 0) {
+        //结束于日期
+        m_endrepeatCombox->setCurrentIndex(2);
+        m_endRepeatDate->setDate(m_scheduleDataInfo->recurrence()->endDateTime().date());
+    } else {
+        //结束与次数
+        m_endrepeatCombox->setCurrentIndex(1);
+        m_endrepeattimes->setText(QString::number(m_scheduleDataInfo->recurrence()->duration() - 1));
+    }
+    sloteRpeatactivated(m_endrepeatCombox->currentIndex());
 }
 
 void CScheduleDlg::setTheMe(const int type)
@@ -1264,13 +1369,15 @@ void CScheduleDlg::setTabFouseOrder()
     setTabOrder(m_rmindCombox, m_beginrepeatCombox);
     setTabOrder(m_beginrepeatCombox, m_endrepeatCombox);
     //结束于次数，设置tab顺序
-    if (m_ScheduleDataInfo.getRepetitionRule().getRuleType() ==
-            RepetitionRule::RRuleEndType::RRuleType_FREQ)
-        setTabOrder(m_endrepeatCombox, m_endrepeattimes);
-    //结束于日期，设置tab顺序
-    if (m_ScheduleDataInfo.getRepetitionRule().getRuleType() ==
-            RepetitionRule::RRuleEndType::RRuleType_DATE)
-        setTabOrder(m_endrepeatCombox, m_endRepeatDate);
+    //如果为重复日程
+    if (!m_scheduleDataInfo.isNull() && m_scheduleDataInfo->getRRuleType() != DSchedule::RRule_None) {
+        //如果为结束于次数
+        if (m_scheduleDataInfo->recurrence()->duration() > 0) {
+            setTabOrder(m_endrepeatCombox, m_endrepeattimes);
+        } else if (m_scheduleDataInfo->recurrence()->duration() == 0) {
+            setTabOrder(m_endrepeatCombox, m_endRepeatDate);
+        }
+    }
 }
 
 void CScheduleDlg::updateIsOneMoreDay(const QDateTime &begin, const QDateTime &end)
@@ -1321,8 +1428,18 @@ bool CScheduleDlg::isShowLunar()
  */
 void CScheduleDlg::setShowState(bool jobIsLunar)
 {
-    //如果不显示农历
-    if (isShowLunar()) {
+    m_solarRadioBtn->setEnabled(true);
+    m_lunarRadioBtn->setEnabled(true);
+    setWidgetEnabled(true);
+    getButton(1)->setEnabled(true);
+    if (!m_accountItem || !m_accountItem->isCanSyncShedule()) {
+        //不可同步日程，除帐户选择外其他的控件都置灰
+        m_solarRadioBtn->setEnabled(false);
+        m_lunarRadioBtn->setEnabled(false);
+        setWidgetEnabled(false);
+        getButton(1)->setEnabled(false);
+    } else if (isShowLunar()) {
+        //如果不显示农历
         m_lunarRadioBtn->setEnabled(true);
         m_beginDateEdit->setLunarCalendarStatus(jobIsLunar);
         m_endDateEdit->setLunarCalendarStatus(jobIsLunar);
@@ -1365,19 +1482,38 @@ void CScheduleDlg::setWidgetEnabled(bool isEnabled)
     m_endRepeatDate->setEnabled(isEnabled);
 }
 
-void CScheduleDlg::initColor()
+void CScheduleDlg::resetColor(const AccountItem::Ptr &account)
 {
+    m_colorSeletorWideget->resetColorButton(account);
     //将用户上一次选择的自定义颜色添加进去
     QString colorName = CConfigSettings::getInstance()->value("LastUserColor", "").toString();
     if (!colorName.isEmpty()) {
-        m_colorSeletorWideget->setUserColor(JobTypeColorInfo(0, colorName, 7));
+        //设置颜色
+        DTypeColor::Ptr typeColor;
+        typeColor.reset(new DTypeColor);
+        typeColor->setColorCode(colorName);
+        typeColor->setPrivilege(DTypeColor::PriUser);
+        m_colorSeletorWideget->setUserColor(typeColor);
     }
-
     //选中上一次选中的颜色
-    int colorId = CConfigSettings::getInstance()->value("LastSysColorTypeNo", -1).toInt();
-    if (colorId > 0) {
-        m_colorSeletorWideget->setSelectedColorById(colorId);
+    QVariant colorId = CConfigSettings::getInstance()->value("LastSysColorTypeNo", -1);
+    int colorNum = 0;
+    if (colorId.type() == QVariant::Int) {
+        //如果是int型表示为旧颜色编号
+        colorNum = colorId.toInt();
+    } else {
+        QString &&colorIdStr = colorId.toString();
+        //如果都为空表示为初始状态，则选中第一个
+        if (colorName.isEmpty() && colorIdStr.isEmpty()) {
+            colorNum = -1;
+        } else if (!colorIdStr.isEmpty()) {
+            //如果颜色id不为空则表示颜色为内置颜色
+            colorNum = GTypeColor.keys().indexOf(colorIdStr);
+        } else {
+            colorNum = 9;
+        }
     }
+    m_colorSeletorWideget->setSelectedColorById(colorNum);
 }
 
 void CScheduleDlg::resize()
@@ -1388,10 +1524,14 @@ void CScheduleDlg::resize()
     }
 
     if (m_colorSeletorWideget->isVisible()) {
-        h += 18 + 5;
+        h += 18 + 10;
     }
-    //524: 默认界面高度, h: 新增控件高度
-    setFixedSize(dialog_width, 524 + h);
+    if (!gAccountManager->getIsSupportUid()) {
+        h -= 36;
+    }
+
+    //573: 默认界面高度, h: 新增控件高度
+    setFixedSize(dialog_width, 573 + h);
 }
 
 void CScheduleDlg::setOkBtnEnabled()
@@ -1401,7 +1541,7 @@ void CScheduleDlg::setOkBtnEnabled()
     //根据类型输入框的内容判断保存按钮是否有效
     if (m_OkBt != nullptr && m_typeComBox->lineEdit() != nullptr) {
         const QString &typeStr = m_typeComBox->lineEdit()->text();
-        if (typeStr.isEmpty() || typeStr.trimmed().isEmpty() || JobTypeInfoManager::instance()->isJobTypeNameUsed(typeStr)) {
+        if (typeStr.isEmpty() || typeStr.trimmed().isEmpty()) {
             m_OkBt->setEnabled(false);
             //若内容无效直接退出，不判断结束次数是否为空
             return;
@@ -1416,4 +1556,10 @@ void CScheduleDlg::setOkBtnEnabled()
         //日期  //永不
         m_OkBt->setEnabled(true);
     }
+
+    if (!m_textEdit->toPlainText().isEmpty() && m_textEdit->toPlainText().trimmed().isEmpty()) {
+        m_OkBt->setEnabled(false);
+    } else {
+        m_OkBt->setEnabled(true);
+    }
 }
