@@ -1,23 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     uniontech  <uniontech@uniontech.com>
-*
-* Maintainer: uniontech  <chenhaifeng@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "draginfographicsview.h"
 #include "scheduledlg.h"
 #include "schedulectrldlg.h"
@@ -27,6 +11,7 @@
 #include "graphicsItem/cscenebackgrounditem.h"
 #include "calendarglobalenv.h"
 #include "scheduledatamanage.h"
+#include "graphicsItem/scheduleitem.h"
 
 #include <DMenu>
 
@@ -46,7 +31,7 @@
 #include <QPainterPath>
 
 //定义拖拽日程
-ScheduleDataInfo DragInfoGraphicsView::m_DragScheduleInfo;
+DSchedule::Ptr DragInfoGraphicsView::m_DragScheduleInfo;
 bool DragInfoGraphicsView::m_hasUpdateMark = false;
 
 DragInfoGraphicsView::DragInfoGraphicsView(DWidget *parent)
@@ -92,12 +77,13 @@ DragInfoGraphicsView::DragInfoGraphicsView(DWidget *parent)
     connect(m_Scene, &CGraphicsScene::signalsetNextFocus, this, &DragInfoGraphicsView::slotsetNextFocus);
     setFocusPolicy(Qt::StrongFocus);
     //日程类型发生改变，刷新界面
-    JobTypeInfoManager::instance()->addToNoticeBill(this->viewport(), "update");
+    connect(gAccountManager, &AccountManager::signalScheduleTypeUpdate, [&]() {
+        this->viewport()->update();
+    });
 }
 
 DragInfoGraphicsView::~DragInfoGraphicsView()
 {
-    JobTypeInfoManager::instance()->removeFromNoticeBill(this->viewport());
 }
 
 void DragInfoGraphicsView::mousePressEvent(QMouseEvent *event)
@@ -227,84 +213,91 @@ void DragInfoGraphicsView::mouseMoveEvent(QMouseEvent *event)
         DragInfoItem::setPressFlag(false);
     }
 
-    DragInfoItem *item = dynamic_cast<DragInfoItem *>(itemAt(event->pos()));
-
-    if (item != nullptr) {
-        if (item->getData().getType() != DDECalendar::FestivalTypeID) {
-            if (m_DragStatus == NONE) {
-                switch (getPosInItem(event->pos(), item->rect())) {
-                case LEFT:
-                case RIGHT:
-                    setCursor(Qt::SplitHCursor);
-                    break;
-                case TOP:
-                case BOTTOM:
-                    setCursor(Qt::SplitVCursor);
-                    break;
-                default:
-                    setCursor(Qt::ArrowCursor);
-                    break;
+    if (m_DragStatus == NONE) {
+        DragInfoItem *item = dynamic_cast<DragInfoItem *>(itemAt(event->pos()));
+        if (item != nullptr) {
+            if (isCanDragge(item->getData())) {
+                if (m_DragStatus == NONE) {
+                    switch (getPosInItem(event->pos(), item->rect())) {
+                    case LEFT:
+                    case RIGHT:
+                        setCursor(Qt::SplitHCursor);
+                        break;
+                    case TOP:
+                    case BOTTOM:
+                        setCursor(Qt::SplitVCursor);
+                        break;
+                    default:
+                        setCursor(Qt::ArrowCursor);
+                        break;
+                    }
                 }
             }
+        } else {
+            if (m_DragStatus == NONE) {
+                setCursor(Qt::ArrowCursor);
+            }
         }
     } else {
-        if (m_DragStatus == NONE) {
-            setCursor(Qt::ArrowCursor);
-        }
-    }
-    QDateTime gDate =  getPosDate(event->pos());
-    switch (m_DragStatus) {
-    case IsCreate:
-        m_isCreate = JudgeIsCreate(event->pos());
-        if (m_isCreate) {
+        QDateTime gDate = getPosDate(event->pos());
+        switch (m_DragStatus) {
+        case IsCreate:
+            if (gDate.date().year() >= DDECalendar::QueryEarliestYear && gDate.date().year() <= DDECalendar::QueryLatestYear) {
+                if (m_PressDate.date().year() >= DDECalendar::QueryEarliestYear && m_PressDate.date().year() <= DDECalendar::QueryLatestYear) {
+                    //如果拖拽创建为false则判断是否可被创建。如果为true则不需要判断
+                    m_isCreate = m_isCreate ? m_isCreate : JudgeIsCreate(event->pos());
+                    if (m_isCreate) {
+                        if (!IsEqualtime(m_MoveDate, gDate)) {
+                            m_MoveDate = gDate;
+                            m_DragScheduleInfo = getScheduleInfo(m_PressDate, m_MoveDate);
+                            upDateInfoShow(IsCreate, m_DragScheduleInfo);
+                            //更新背景上显示的item
+                            updateBackgroundShowItem();
+                            setPressSelectInfo(m_DragScheduleInfo);
+                        }
+                    }
+                }
+            }
+            break;
+        case ChangeBegin:
             if (!IsEqualtime(m_MoveDate, gDate)) {
                 m_MoveDate = gDate;
-                m_DragScheduleInfo = getScheduleInfo(m_PressDate, m_MoveDate);
-                upDateInfoShow(IsCreate, m_DragScheduleInfo);
-                //更新背景上显示的item
-                updateBackgroundShowItem();
-                setPressSelectInfo(m_DragScheduleInfo);
+                //获取日程开始时间
+                QDateTime _beginTime = getDragScheduleInfoBeginTime(m_MoveDate);
+                m_DragScheduleInfo->setDtStart(_beginTime);
+                m_DragScheduleInfo->setDtEnd(m_InfoEndTime);
+                upDateInfoShow(ChangeBegin, m_DragScheduleInfo);
             }
-        }
-        break;
-    case ChangeBegin:
-        if (!IsEqualtime(m_MoveDate, gDate)) {
-            m_MoveDate = gDate;
-            //获取日程开始时间
-            QDateTime _beginTime = getDragScheduleInfoBeginTime(m_MoveDate);
-            m_DragScheduleInfo.setBeginDateTime(_beginTime);
-            m_DragScheduleInfo.setEndDateTime(m_InfoEndTime);
-            upDateInfoShow(ChangeBegin, m_DragScheduleInfo);
-        }
-        break;
-    case ChangeEnd:
-        if (!IsEqualtime(m_MoveDate, gDate)) {
-            m_MoveDate = gDate;
-            m_DragScheduleInfo.setBeginDateTime(m_InfoBeginTime);
-            //获取结束时间
-            QDateTime _endTime = getDragScheduleInfoEndTime(m_MoveDate);
-            m_DragScheduleInfo.setEndDateTime(_endTime);
-            upDateInfoShow(ChangeEnd, m_DragScheduleInfo);
-        }
-        break;
-    case ChangeWhole: {
-        if (!m_PressRect.contains(event->pos())) {
-            //拖拽前设置是否已经更新日程界面标志为否
-            m_hasUpdateMark = false;
-            m_Drag->exec(Qt::MoveAction);
-            m_Drag = nullptr;
-            m_DragStatus = NONE;
-            setCursor(Qt::ArrowCursor);
-            //如果拖拽结束后没有修改日程则更新下界面日程显示
-            if (!m_hasUpdateMark) {
-                updateInfo();
+            break;
+        case ChangeEnd:
+            if (!IsEqualtime(m_MoveDate, gDate)) {
+                m_MoveDate = gDate;
+                m_DragScheduleInfo->setDtStart(m_InfoBeginTime);
+                //获取结束时间
+                QDateTime _endTime = getDragScheduleInfoEndTime(m_MoveDate);
+                m_DragScheduleInfo->setDtEnd(_endTime);
+                upDateInfoShow(ChangeEnd, m_DragScheduleInfo);
             }
+            break;
+        case ChangeWhole: {
+            if (!m_PressRect.contains(event->pos())) {
+                //拖拽前设置是否已经更新日程界面标志为否
+                m_hasUpdateMark = false;
+                m_Drag->exec(Qt::MoveAction);
+                m_Drag = nullptr;
+                m_DragStatus = NONE;
+                setCursor(Qt::ArrowCursor);
+                //如果拖拽结束后没有修改日程则更新下界面日程显示
+                if (!m_hasUpdateMark) {
+                    updateInfo();
+                }
+            }
+        } break;
+        default:
+            break;
         }
     }
-    break;
-    default:
-        break;
-    }
+
     DGraphicsView::mouseMoveEvent(event);
 }
 
@@ -329,11 +322,19 @@ void DragInfoGraphicsView::contextMenuEvent(QContextMenuEvent *event)
     QGraphicsItem *listItem = itemAt(event->pos());
     DragInfoItem *infoitem = dynamic_cast<DragInfoItem *>(listItem);
 
+    CScheduleItem *tt = dynamic_cast<CScheduleItem *>(listItem);
+    if (tt != nullptr && tt->getType() != 0) {
+        return;
+    }
     if (infoitem != nullptr) {
-        if (infoitem->getData().getType() != DDECalendar::FestivalTypeID) {
+        //是否为节假日日程判断
+        if (!CScheduleOperation::isFestival(infoitem->getData())) {
             m_rightMenu->clear();
             m_rightMenu->addAction(m_editAction);
             m_rightMenu->addAction(m_deleteAction);
+            //如果日程是不可修改的则设置删除按钮无效
+            m_deleteAction->setEnabled(!CScheduleOperation::scheduleIsInvariant(infoitem->getData()));
+
             QAction *action_t = m_rightMenu->exec(QCursor::pos());
 
             if (action_t == m_editAction) {
@@ -357,17 +358,17 @@ void DragInfoGraphicsView::contextMenuEvent(QContextMenuEvent *event)
 void DragInfoGraphicsView::dragEnterEvent(QDragEnterEvent *event)
 {
     if (event->mimeData()->hasFormat("Info")) {
-        QJsonParseError json_error;
         QString str = event->mimeData()->data("Info");
-        QJsonDocument jsonDoc(QJsonDocument::fromJson(str.toLocal8Bit(), &json_error));
+        DSchedule::Ptr info;
+        DSchedule::fromJsonString(info, str);
 
-        if (json_error.error != QJsonParseError::NoError) {
+        if (info.isNull()) {
             event->ignore();
         }
-        QJsonObject rootobj = jsonDoc.object();
-        ScheduleDataInfo info = ScheduleDataInfo::JsonToSchedule(rootobj);
 
-        if ((event->source() != this && info.getRepetitionRule().getRuleId() > 0) || info.getType() == DDECalendar::FestivalTypeID) {
+        //如果该日程是不能被拖拽的则忽略不接受
+        //重复日程不能被切换全天和非全天
+        if ((event->source() != this && info->recurs()) || !isCanDragge(info)) {
             event->ignore();
         } else {
             event->accept();
@@ -400,8 +401,8 @@ void DragInfoGraphicsView::dragMoveEvent(QDragMoveEvent *event)
     if (!IsEqualtime(m_MoveDate, gDate)) {
         m_MoveDate = gDate;
         QJsonObject rootobj = jsonDoc.object();
-        m_DragScheduleInfo = ScheduleDataInfo::JsonToSchedule(rootobj);
-        m_DragScheduleInfo.setIsMoveInfo(true);
+        DSchedule::fromJsonString(m_DragScheduleInfo, str);
+        m_DragScheduleInfo->setMoved(true);
         MoveInfoProcess(m_DragScheduleInfo, event->posF());
         DragInfoItem::setPressSchedule(m_DragScheduleInfo);
     }
@@ -411,12 +412,19 @@ void DragInfoGraphicsView::dropEvent(QDropEvent *event)
 {
     if (event->mimeData()->hasFormat("Info")) {
         if (event->source() != this || m_MoveDate != m_PressDate) {
-            updateScheduleInfo(m_DragScheduleInfo);
-        } else {
-            emit signalsUpdateSchedule();
+            //后面方法出现模态框，阻塞，导致拖拽图片不消失，手动先调用取消接口解决
+            QDrag::cancel();
+
+            auto startDate = m_DragScheduleInfo->dtStart();
+            auto endDate = m_DragScheduleInfo->dtEnd();
+            if (startDate.date().year() >= DDECalendar::QueryEarliestYear && endDate.date().year() <= DDECalendar::QueryLatestYear) {
+                updateScheduleInfo(m_DragScheduleInfo);
+            } else {
+                emit signalsUpdateSchedule();
+            }
+            m_DragStatus = NONE;
+            m_MoveDate = m_MoveDate.addMonths(-2);
         }
-        m_DragStatus = NONE;
-        m_MoveDate = m_MoveDate.addMonths(-2);
     }
 }
 
@@ -481,7 +489,7 @@ void DragInfoGraphicsView::slotCreate()
  * @brief DragInfoGraphicsView::setPressSelectInfo      设置点击选中日程
  * @param info
  */
-void DragInfoGraphicsView::setPressSelectInfo(const ScheduleDataInfo &info)
+void DragInfoGraphicsView::setPressSelectInfo(const DSchedule::Ptr &info)
 {
     DragInfoItem::setPressSchedule(info);
 }
@@ -490,14 +498,14 @@ void DragInfoGraphicsView::setPressSelectInfo(const ScheduleDataInfo &info)
  * @brief DragInfoGraphicsView::updateScheduleInfo      拖拽更新日程信息
  * @param info
  */
-void DragInfoGraphicsView::updateScheduleInfo(const ScheduleDataInfo &info)
+void DragInfoGraphicsView::updateScheduleInfo(const DSchedule::Ptr &info)
 {
     QVariant variant;
     //获取主窗口指针
     CalendarGlobalEnv::getGlobalEnv()->getValueByKey("MainWindow", variant);
     QObject *parent = static_cast<QObject *>(variant.value<void *>());
     //设置父类为主窗口
-    CScheduleOperation _scheduleOperation(qobject_cast<QWidget *>(parent));
+    CScheduleOperation _scheduleOperation(info->scheduleTypeID(), qobject_cast<QWidget *>(parent));
     if (_scheduleOperation.changeSchedule(info, m_PressScheduleInfo)) {
         //如果日程修改成功则更新更新标志
         m_hasUpdateMark = true;
@@ -517,13 +525,14 @@ void DragInfoGraphicsView::DragPressEvent(const QPoint &pos, DragInfoItem *item)
 
     if (item != nullptr) {
         PosInItem mpressstatus = getPosInItem(pos, item->boundingRect());
-        if (mpressstatus != MIDDLE && item->getData().getType() == 4) {
+        if (mpressstatus != MIDDLE && !isCanDragge(item->getData())) {
             return;
         }
-        m_DragScheduleInfo = item->getData();
+        //拖拽使用副本，不更改原始日程
+        m_DragScheduleInfo.reset(item->getData()->clone());
         m_PressScheduleInfo = item->getData();
-        m_InfoBeginTime = m_DragScheduleInfo.getBeginDateTime();
-        m_InfoEndTime = m_DragScheduleInfo.getEndDateTime();
+        m_InfoBeginTime = m_DragScheduleInfo->dtStart();
+        m_InfoEndTime = m_DragScheduleInfo->dtEnd();
         switch (mpressstatus) {
         case TOP:
             m_DragStatus = ChangeBegin;
@@ -545,8 +554,11 @@ void DragInfoGraphicsView::DragPressEvent(const QPoint &pos, DragInfoItem *item)
             ShowSchedule(item);
             m_DragStatus = ChangeWhole;
             QMimeData *mimeData = new QMimeData();
-            mimeData->setText(m_DragScheduleInfo.getTitleName());
-            mimeData->setData("Info", ScheduleDataInfo::ScheduleToJsonStr(m_DragScheduleInfo).toUtf8());
+            mimeData->setText(m_DragScheduleInfo->summary());
+            QString strData;
+            DSchedule::toJsonString(m_DragScheduleInfo, strData);
+            //数据转换
+            mimeData->setData("Info", strData.toUtf8());
 
             if (m_Drag == nullptr) {
                 m_Drag = new QDrag(this);
@@ -587,7 +599,7 @@ void DragInfoGraphicsView::mouseReleaseScheduleUpdate()
                 updateInfo();
             }
             //设置选中日程为无效日程
-            setPressSelectInfo(ScheduleDataInfo());
+            setPressSelectInfo(DSchedule::Ptr());
         }
         break;
     case ChangeBegin:
@@ -613,21 +625,33 @@ void DragInfoGraphicsView::mouseReleaseScheduleUpdate()
 
 void DragInfoGraphicsView::mousePress(const QPoint &point)
 {
-    setPressSelectInfo(ScheduleDataInfo());
+    setPressSelectInfo(DSchedule::Ptr());
     //设置拖拽日程为无效日程
-    m_DragScheduleInfo = ScheduleDataInfo();
+    m_DragScheduleInfo = DSchedule::Ptr();
     pressScheduleInit();
     QGraphicsItem *listItem = itemAt(point);
     DragInfoItem *infoitem = dynamic_cast<DragInfoItem *>(listItem);
-
-    if (infoitem != nullptr) {
+    //不满足拖拽条件的日程不进行拖拽事件
+    if (infoitem) {
         setPressSelectInfo(infoitem->getData());
+        m_PressScheduleInfo = infoitem->getData();
         m_press = true;
-        DragInfoItem::setPressFlag(true);
+        if (isCanDragge(infoitem->getData())) {
+            //满足拖拽条件
+            DragInfoItem::setPressFlag(true);
+            DragPressEvent(point, infoitem);
+        } else {
+            //不满足拖拽条件，只展示信息弹窗
+            m_PressPos = point;
+            m_PressDate = getPosDate(point);
+            CalendarGlobalEnv::getGlobalEnv()->reviseValue(DDECalendar::CursorPointKey, mapToGlobal(point));
+            ShowSchedule(infoitem);
+        }
     } else {
+        //没有日程信息，可滑动
         emit signalScheduleShow(false);
+        DragPressEvent(point, infoitem);
     }
-    DragPressEvent(point, infoitem);
     this->scene()->update();
     update();
 }
@@ -652,10 +676,11 @@ void DragInfoGraphicsView::stopTouchAnimation()
  * @brief DragInfoGraphicsView::DeleteItem      删除日程
  * @param info
  */
-void DragInfoGraphicsView::DeleteItem(const ScheduleDataInfo &info)
+void DragInfoGraphicsView::DeleteItem(const DSchedule::Ptr &info)
 {
+    if (info.isNull()) return;
     //删除日程
-    CScheduleOperation _scheduleOperation(this);
+    CScheduleOperation _scheduleOperation(info->scheduleTypeID(), this);
     _scheduleOperation.deleteSchedule(info);
 }
 
@@ -663,7 +688,7 @@ void DragInfoGraphicsView::DeleteItem(const ScheduleDataInfo &info)
  * @brief DragInfoGraphicsView::setSelectSearchSchedule     设置选中搜索日程
  * @param scheduleInfo
  */
-void DragInfoGraphicsView::setSelectSearchSchedule(const ScheduleDataInfo &scheduleInfo)
+void DragInfoGraphicsView::setSelectSearchSchedule(const DSchedule::Ptr &scheduleInfo)
 {
     setPressSelectInfo(scheduleInfo);
 }
@@ -698,22 +723,23 @@ void DragInfoGraphicsView::slotCreate(const QDateTime &date)
     }
 }
 
-ScheduleDataInfo DragInfoGraphicsView::getScheduleInfo(const QDateTime &beginDate, const QDateTime &endDate)
+DSchedule::Ptr DragInfoGraphicsView::getScheduleInfo(const QDateTime &beginDate, const QDateTime &endDate)
 {
-    ScheduleDataInfo info;
-
+    DSchedule::Ptr info;
+    info.reset(new DSchedule());
     if (beginDate.daysTo(endDate) > 0) {
-        info.setBeginDateTime(QDateTime(beginDate.date(), QTime(0, 0, 0)));
-        info.setEndDateTime(QDateTime(endDate.date(), QTime(23, 59, 59)));
+        info->setDtStart(QDateTime(beginDate.date(), QTime(0, 0, 0)));
+        info->setDtEnd(QDateTime(endDate.date(), QTime(23, 59, 59)));
     } else {
-        info.setBeginDateTime(QDateTime(endDate.date(), QTime(0, 0, 0)));
-        info.setEndDateTime(QDateTime(beginDate.date(), QTime(23, 59, 00)));
+        info->setDtStart(QDateTime(endDate.date(), QTime(0, 0, 0)));
+        info->setDtEnd(QDateTime(beginDate.date(), QTime(23, 59, 00)));
     }
-    info.setTitleName(tr("New Event"));
-    info.setAllDay(true);
-    info.setRemindData(RemindData(1, QTime(9, 0)));
-    info.setID(0);
-    info.setRecurID(0);
+    info->setSummary(tr("New Event"));
+    info->setAllDay(true);
+    //设置默认日程类型为工作
+    info->setScheduleTypeID("107c369e-b13a-4d45-9ff3-de4eb3c0475b");
+    //设置提醒规则
+    info->setAlarmType(DSchedule::Alarm_15Hour_Front);
     return info;
 }
 
@@ -780,8 +806,8 @@ void DragInfoGraphicsView::slideEvent(QPointF &startPoint, QPointF &stopPort)
 void DragInfoGraphicsView::updateInfo()
 {
     //如果拖拽日程有效则更新为不是移动日程
-    if (m_DragScheduleInfo.isValid() && m_DragScheduleInfo.getID() != 0) {
-        m_DragScheduleInfo.setIsMoveInfo(false);
+    if (m_DragScheduleInfo && m_DragScheduleInfo->isValid() && m_DragScheduleInfo->uid() != "0") {
+        m_DragScheduleInfo->setMoved(false);
         //设置选择日程状态
         setPressSelectInfo(m_DragScheduleInfo);
     }
@@ -798,13 +824,30 @@ void DragInfoGraphicsView::setShowRadius(bool leftShow, bool rightShow)
     m_rightShowRadius = rightShow;
 }
 
+bool DragInfoGraphicsView::isCanDragge(const DSchedule::Ptr &info)
+{
+    if (info.isNull() || info->scheduleTypeID().isEmpty())
+        return false;
+    //是否为节假日日程判断
+    if (CScheduleOperation::isFestival(info))
+        return false;
+    if (info->lunnar() && !QLocale::system().name().startsWith("zh_"))
+        return false;
+    //日程不可被修改
+    if (CScheduleOperation::scheduleIsInvariant(info)) {
+        return false;
+    }
+    return true;
+}
+
 /**
  * @brief DragInfoGraphicsView::slotDeleteItem      删除日程
  */
 void DragInfoGraphicsView::slotDeleteItem()
 {
     //获取选中日程
-    ScheduleDataInfo _pressSchedule = DragInfoItem::getPressSchedule();
+    DSchedule::Ptr _pressSchedule = DragInfoItem::getPressSchedule();
+
     //根据焦点状态获取当前焦点的item
     CSceneBackgroundItem *backgroundItem = dynamic_cast<CSceneBackgroundItem *>(m_Scene->getCurrentFocusItem());
     if (backgroundItem != nullptr) {
@@ -816,12 +859,15 @@ void DragInfoGraphicsView::slotDeleteItem()
         }
     }
 
-    //判断是否有效,如果为有效日程且日程类型不为节日或纪念日则删除
-    if (_pressSchedule.isValid() && _pressSchedule.getType() != 4) {
-        CScheduleOperation _scheduleOperation(this);
+    //判断是否有效,如果为有效日程且日程类型不为节日或纪念日或不可更改日程则删除
+    //判断日程信息
+    if (!_pressSchedule.isNull() && _pressSchedule->isValid()
+            && !CScheduleOperation::isFestival(_pressSchedule)
+            && !CScheduleOperation::scheduleIsInvariant(_pressSchedule)) {
+        CScheduleOperation _scheduleOperation(_pressSchedule->scheduleTypeID(), this);
         _scheduleOperation.deleteSchedule(_pressSchedule);
         //设置选择日程为无效日程
-        setPressSelectInfo(ScheduleDataInfo());
+        setPressSelectInfo(DSchedule::Ptr());
         //设置拖拽日程为无效日程
         m_DragScheduleInfo = DragInfoItem::getPressSchedule();
     }
@@ -853,13 +899,15 @@ void DragInfoGraphicsView::slotContextMenu(CFocusItem *item)
     DragInfoItem *infoitem = dynamic_cast<DragInfoItem *>(item);
     if (infoitem != nullptr) {
         //如果为节假日则退出不展示右击菜单
-        if (infoitem->getData().getType() == 4)
+        if (CScheduleOperation::isFestival(infoitem->getData()))
             return;
         //快捷键调出右击菜单
         m_Scene->setIsContextMenu(true);
         m_rightMenu->clear();
         m_rightMenu->addAction(m_editAction);
         m_rightMenu->addAction(m_deleteAction);
+        //如果日程不可修改则设置删除无效
+        m_deleteAction->setEnabled(!CScheduleOperation::scheduleIsInvariant(infoitem->getData()));
         QPointF itemPos = QPointF(infoitem->rect().x() + infoitem->rect().width() / 2, infoitem->rect().y() + infoitem->rect().height() / 2);
         QPointF scene_pos = infoitem->mapToScene(itemPos);
         QPointF view_pos = mapFromScene(scene_pos);
@@ -898,7 +946,7 @@ void DragInfoGraphicsView::setSceneCurrentItemFocus(const QDate &focusDate)
  */
 void DragInfoGraphicsView::pressScheduleInit()
 {
-    m_PressScheduleInfo = ScheduleDataInfo();
+    m_PressScheduleInfo = DSchedule::Ptr();
 }
 
 QDate DragInfoGraphicsView::getCurrentDate() const
