@@ -1,27 +1,14 @@
-/*
- * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     kirigaya <kirigaya@mkacg.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "calendarmainwindow.h"
 #include "widget/yearWidget/yearwindow.h"
 #include "widget/monthWidget/monthwindow.h"
 #include "dbuscalendar_adaptor.h"
 #include "widget/weekWidget/weekwindow.h"
 #include "widget/dayWidget/daywindow.h"
+#include "sidebarWidget/sidebarview.h"
 #include "colorWidget/colorpickerWidget.h"
 #include "scheduledatamanage.h"
 #include "myscheduleview.h"
@@ -34,19 +21,25 @@
 #include "ctitlewidget.h"
 #include "tabletconfig.h"
 #include "calendarglobalenv.h"
+#include "settingWidget/userloginwidget.h"
+#include "settingWidget/settingwidgets.h"
 
 #include "scheduletypeeditdlg.h"
+#include "accountmanager.h"
+#include "units.h"
+#include "commondef.h"
+
 
-#include <DHiDPIHelper>
 #include <DPalette>
 #include <DFontSizeManager>
 #include <DWidgetUtil>
 #include <DTitlebar>
-#include <DApplicationHelper>
 #include <DSettings>
 #include <DSettingsGroup>
 #include <DSettingsOption>
 #include <DSettingsWidgetFactory>
+#include <DBackgroundGroup>
+#include <DMessageManager>
 
 #include <QDesktopWidget>
 #include <QJsonDocument>
@@ -56,10 +49,16 @@
 #include <QSizePolicy>
 #include <QHBoxLayout>
 #include <QWidget>
+#include <QScreen>
 #include <QMenuBar>
 #include <QMouseEvent>
 #include <QColorDialog>
 #include <QApplication>
+#include <QWidgetAction>
+#include <QDesktopServices>
+
+#include <stdlib.h>
+#include <functional>
 
 DGUI_USE_NAMESPACE
 DWIDGET_USE_NAMESPACE
@@ -72,6 +71,10 @@ const int CalendarViewSwitchWidth = 804; //当宽度小于这个尺寸时，视
 const int Calendar_Default_Width = 860; //默认宽度
 const int Calendar_Default_Height = 634; //默认高度
 
+//静态的翻译不会真的翻译，但是会更新ts文件
+//像static QString a = QObject::tr("hello"), a实际等于hello，但是ts会有hello这个词条
+//调用DSetingDialog时会用到上述场景
+
 Calendarmainwindow::Calendarmainwindow(int index, QWidget *w)
     : DMainWindow(w)
     , m_defaultIndex(index)
@@ -79,6 +82,7 @@ Calendarmainwindow::Calendarmainwindow(int index, QWidget *w)
     setContentsMargins(QMargins(0, 0, 0, 0));
     initUI();
     initConnection();
+    initData();
     setMinimumSize(CalendarMWidth, CalendarMHeight);
     setWindowTitle(tr("Calendar"));
     new CalendarAdaptor(this);
@@ -94,11 +98,11 @@ Calendarmainwindow::Calendarmainwindow(int index, QWidget *w)
     connect(viewshortcut, SIGNAL(activated()), this, SLOT(slotViewShortcut()));
 
     setTitlebarShadowEnabled(true);
-    //获取桌面窗口大小
-    QDesktopWidget *desktopwidget = QApplication::desktop();
     //若分辨率改变则重新设置最大尺寸
-    connect(desktopwidget, &QDesktopWidget::resized, this, &Calendarmainwindow::slotSetMaxSize);
-    slotSetMaxSize();
+    const auto screens = QGuiApplication::screens();
+    for (QScreen *screen : screens) {
+        connect(screen, &QScreen::geometryChanged, this, &Calendarmainwindow::slotSetMaxSize);
+    }
 
     //兼容以前的配置信息
     if (CConfigSettings::getInstance()->contains("base.geometry")) {
@@ -198,7 +202,7 @@ void Calendarmainwindow::slotSetSearchFocus()
 void Calendarmainwindow::viewWindow(int type, const bool showAnimation)
 {
     if (type < 0 || type >= m_stackWidget->count()) {
-        qWarning() << "set view error,set index:" << type;
+        qCWarning(ClientLogger) << "set view error,set index:" << type;
         return;
     }
     if (showAnimation) {
@@ -300,8 +304,8 @@ void Calendarmainwindow::slotOpenSchedule(QString job)
 {
     if (job.isEmpty())
         return;
-    ScheduleDataInfo out;
-    out = ScheduleDataInfo::JsonStrToSchedule(job);
+    DSchedule::Ptr out;
+    DSchedule::fromJsonString(out, job);
 
     //设置被选中
     m_buttonBox->button(DDECalendar::CalendarDayWindow)->setChecked(true);
@@ -310,14 +314,20 @@ void Calendarmainwindow::slotOpenSchedule(QString job)
     //切换到日视图
     m_stackWidget->setCurrentIndex(DDECalendar::CalendarDayWindow);
     //设置选择时间
-    m_DayWindow->setSelectDate(out.getBeginDateTime().date());
+    m_DayWindow->setSelectDate(out->dtStart().date());
     //更新界面显示
     m_DayWindow->updateData();
     //设置非全天时间定位位置
-    m_DayWindow->setTime(out.getBeginDateTime().time());
+    m_DayWindow->setTime(out->dtStart().time());
     //弹出编辑对话框
-    CMyScheduleView dlg(out, this);
-    dlg.exec();
+    if (m_dlg == Q_NULLPTR) {
+        m_dlg = new CMyScheduleView(out, this);
+    } else {
+        m_dlg->setSchedules(out);
+        m_dlg->updateFormat();
+    }
+    if (m_dlg->isHidden())
+        m_dlg->exec();
     slotWUpdateSchedule();
 }
 void Calendarmainwindow::initUI()
@@ -339,7 +349,6 @@ void Calendarmainwindow::initUI()
     setTabOrder(this->titlebar(), m_titleWidget);
     //设置状态栏焦点代理为标题窗口
     this->titlebar()->setFocusProxy(m_titleWidget);
-    //this->titlebar()->setFocusProxy(titleWidget);
 
     this->titlebar()->setQuitMenuVisible(true);//先设置后，才可以获取menu内容。因为setQuitMenuVisible接口中进行了action的添加操作
     QMenu *menuTitleBar = this->titlebar()->menu();
@@ -348,11 +357,16 @@ void Calendarmainwindow::initUI()
     //menuTitleBar->addAction(pSetting);
     menuTitleBar->insertSeparator(menuTitleBar->actions()[0]);
     menuTitleBar->insertAction(menuTitleBar->actions()[0], pSetting);
-
     connect(pSetting, &QAction::triggered, this, &Calendarmainwindow::slotOpenSettingDialog);
 
+    //添加隐私政策
+    QAction *pPrivacy = new QAction(tr("Privacy Policy"), menuTitleBar);
+    menuTitleBar->insertSeparator(menuTitleBar->actions()[1]);
+    menuTitleBar->insertAction(menuTitleBar->actions()[1], pPrivacy);
+    connect(pPrivacy, &QAction::triggered, this, &Calendarmainwindow::slotShowPrivacy);
+
     //接收设置按键焦点
-    connect(m_titleWidget, &CTitleWidget::signalSetButtonFocus, [=] {
+    connect(m_titleWidget, &CTitleWidget::signalSetButtonFocus, [ = ] {
         m_setButtonFocus = true;
     });
     connect(m_titleWidget, &CTitleWidget::signalSearchFocusSwitch, this,
@@ -362,6 +376,13 @@ void Calendarmainwindow::initUI()
     m_buttonBox = m_titleWidget->buttonBox();
     m_newScheduleBtn = m_titleWidget->newScheduleBtn();
 
+    QHBoxLayout *tMainLayout = new QHBoxLayout;
+    tMainLayout->setContentsMargins(10, 10, 10, 10);
+    tMainLayout->setSpacing(10);
+
+    m_sidebarView = new SidebarView(this);
+    tMainLayout->addWidget(m_sidebarView, 1);
+
     m_stackWidget = new AnimationStackedWidget();
     m_stackWidget->setObjectName("StackedWidget");
     m_stackWidget->setAccessibleName("StackedWidget");
@@ -369,11 +390,9 @@ void Calendarmainwindow::initUI()
     m_stackWidget->setContentsMargins(0, 0, 0, 0);
     m_stackWidget->setDuration(250);
     createview();
-    QHBoxLayout *tMainLayout = new QHBoxLayout;
-    tMainLayout->setMargin(0);
-    tMainLayout->setSpacing(0);
-    tMainLayout->setContentsMargins(0, 0, 0, 0);
-    tMainLayout->addWidget(m_stackWidget);
+
+    tMainLayout->addWidget(m_stackWidget, 4);
+
     m_contentBackground = new DFrame;
     m_contentBackground->setAccessibleName("ScheduleSearchWidgetBackgroundFrame");
     m_contentBackground->setObjectName("ScheduleSearchWidgetBackgroundFrame");
@@ -391,12 +410,12 @@ void Calendarmainwindow::initUI()
     QVBoxLayout *ssLayout = new QVBoxLayout;
     ssLayout->setMargin(0);
     ssLayout->setSpacing(0);
-    ssLayout->setContentsMargins(0, 10, 0, 10);
-    ssLayout->addWidget(m_scheduleSearchView);
+    ssLayout->addWidget(m_scheduleSearchView, 1);
     m_contentBackground->setLayout(ssLayout);
-    tMainLayout->addWidget(m_contentBackground);
     m_contentBackground->setVisible(false);
 
+    tMainLayout->addWidget(m_contentBackground);
+
     DWidget *maincentralWidget = new DWidget(this);
     maincentralWidget->setAccessibleName("mainCentralWidget");
 
@@ -431,10 +450,9 @@ void Calendarmainwindow::initConnection()
             &Calendarmainwindow::slotSearchSelectSchedule);
     connect(m_scheduleSearchView, &CScheduleSearchView::signalScheduleHide, this,
             &Calendarmainwindow::setScheduleHide);
-
+    connect(m_sidebarView, &SidebarView::signalScheduleHide, this, &Calendarmainwindow::setScheduleHide);
     connect(m_scheduleSearchView, &CScheduleSearchView::signalSelectCurrentItem, this,
             &Calendarmainwindow::slotSetSearchFocus);
-
     //更新当前时间
     connect(m_currentDateUpdateTimer, &QTimer::timeout, this,
             &Calendarmainwindow::slotCurrentDateUpdate);
@@ -446,6 +464,16 @@ void Calendarmainwindow::initConnection()
     connect(m_newScheduleBtn, &DToolButton::clicked, this, &Calendarmainwindow::slotNewSchedule);
 
     connect(qApp, &QGuiApplication::applicationStateChanged, this, &Calendarmainwindow::slotapplicationStateChanged);
+    connect(m_titleWidget, &CTitleWidget::signalSidebarStatusChange, this, &Calendarmainwindow::slotSidebarStatusChange);
+    //signalAccountUpdate
+    connect(gAccountManager, &AccountManager::signalSyncNum, this, &Calendarmainwindow::slotShowSyncToast);
+    connect(gAccountManager, &AccountManager::signalAccountUpdate, this, &Calendarmainwindow::slotAccountUpdate);
+}
+
+void Calendarmainwindow::initData()
+{
+    //根据配置设置侧边栏状态
+    m_titleWidget->setSidebarStatus(gSetting->getUserSidebarStatus());
 }
 
 /**
@@ -475,7 +503,7 @@ void Calendarmainwindow::createview()
     //如果默认视图不在范围内则设置为月窗口显示
     if (m_defaultIndex < 0 || m_defaultIndex >= m_stackWidget->count()) {
         m_defaultIndex = 1;
-        qWarning() << "set default view index beyond,index:" << m_defaultIndex;
+        qCWarning(ClientLogger) << "set default view index beyond,index:" << m_defaultIndex;
     }
     m_stackWidget->setCurrentIndex(m_defaultIndex);
     m_buttonBox->button(m_defaultIndex)->setChecked(true);
@@ -485,6 +513,59 @@ void Calendarmainwindow::createview()
     }
 }
 
+void Calendarmainwindow::resizeView()
+{
+    //帐户列表窗口（A），视图窗口(B),搜索结果窗口(C)
+    //窗口由大变小先隐藏A，在隐藏B
+    //窗口由小变大先显示B，在显示A
+    //不能出现只显示A和C的情况
+
+
+    //根据界面大小改变趋势设置侧边栏可显示状态
+    //如果帐户列表窗口为显示状态
+    if (m_titleWidget->getSidevarStatus()) {
+        //如果显示搜索窗口，若需要显示帐户列表则界面的最小尺寸需要984，否则为826
+        int minWidth = m_opensearchflag ? 984 : 826 ;
+
+        if (width() < minWidth) {
+            m_titleWidget->setSidebarCanDisplay(false);
+            m_sidebarView->setVisible(false);
+        } else if (width() > minWidth) {
+            m_titleWidget->setSidebarCanDisplay(true);
+            m_sidebarView->setVisible(true);
+        }
+    }
+
+    m_transparentFrame->resize(width(), height() - 50);
+
+    if (width() < CalendarSwitchWidth) {
+        m_titleWidget->setShowState(CTitleWidget::Title_State_Mini);
+    } else {
+        m_titleWidget->setShowState(CTitleWidget::Title_State_Normal);
+    }
+
+    int sidWidth = 0;
+    if (!m_sidebarView->isHidden()) {
+        sidWidth = m_sidebarView->width();
+    }
+    if (width() < CalendarViewSwitchWidth + sidWidth) {
+        m_isNormalStateShow = false;
+        m_stackWidget->setVisible(!m_contentBackground->isVisible());
+        // 如果是隐藏的状态，不需要多减去sidewidth
+        sidWidth = sidWidth == 0 ? 0 : sidWidth + 10;
+        m_scheduleSearchViewMaxWidth = this->width() - sidWidth;
+    } else {
+        m_scheduleSearchViewMaxWidth = qRound(0.2325 * (width()) + 0.5);
+        m_isNormalStateShow = true;
+        m_stackWidget->setVisible(true);
+        m_contentBackground->setVisible(m_opensearchflag);
+    }
+    // 额外减去20 是因为ui走查控件之间的space=10，两个间隔
+    m_scheduleSearchView->setMaxWidth(m_scheduleSearchViewMaxWidth - 20);
+    setSearchWidth(m_scheduleSearchViewMaxWidth - 20);
+    setScheduleHide();
+}
+
 /**
  * @brief Calendarmainwindow::setScheduleHide       隐藏提示框
  */
@@ -499,27 +580,8 @@ void Calendarmainwindow::setScheduleHide()
 void Calendarmainwindow::resizeEvent(QResizeEvent *event)
 {
     DMainWindow::resizeEvent(event);
-    m_transparentFrame->resize(width(), height() - 50);
 
-    if (width() < CalendarSwitchWidth) {
-        m_titleWidget->setShowState(CTitleWidget::Title_State_Mini);
-    } else {
-        m_titleWidget->setShowState(CTitleWidget::Title_State_Normal);
-    }
-
-    if (width() < CalendarViewSwitchWidth) {
-        m_isNormalStateShow = false;
-        m_stackWidget->setVisible(!m_contentBackground->isVisible());
-        m_scheduleSearchViewMaxWidth = this->width();
-    } else {
-        m_scheduleSearchViewMaxWidth = qRound(0.2325 * width() + 0.5);
-        m_isNormalStateShow = true;
-        m_stackWidget->setVisible(true);
-        m_contentBackground->setVisible(m_opensearchflag);
-    }
-    m_scheduleSearchView->setMaxWidth(m_scheduleSearchViewMaxWidth);
-    setSearchWidth(m_scheduleSearchViewMaxWidth);
-    setScheduleHide();
+    resizeView();
 
     //保存窗口大小
     CConfigSettings::getInstance()->setOption("base.windowWidth", event->size().width());
@@ -552,15 +614,11 @@ void Calendarmainwindow::slotSreturnPressed()
         m_opensearchflag = true;
     }
     //如果为搜索状态
-    if (m_opensearchflag) {
-        //根据显示显示状态，是否显示左侧视图窗口
-        if (!m_isNormalStateShow) {
-            m_stackWidget->setVisible(false);
-        }
-        m_contentBackground->setVisible(true);
-    }
+    m_contentBackground->setVisible(m_opensearchflag);
+
     m_scheduleSearchView->slotsetSearch(m_searchEdit->text());
     updateHeight();
+    resizeView();
 }
 
 void Calendarmainwindow::slotStextChanged()
@@ -579,6 +637,7 @@ void Calendarmainwindow::slotStextChanged()
         m_contentBackground->setVisible(false);
         m_stackWidget->setVisible(true);
         m_opensearchflag = false;
+        resizeView();
     }
     updateHeight();
 }
@@ -603,13 +662,11 @@ void Calendarmainwindow::slotSearchEdit()
  * @brief Calendarmainwindow::slotSearchSelectSchedule  单击搜索日程动画设置
  * @param scheduleInfo
  */
-void Calendarmainwindow::slotSearchSelectSchedule(const ScheduleDataInfo &scheduleInfo)
+void Calendarmainwindow::slotSearchSelectSchedule(const DSchedule::Ptr &scheduleInfo)
 {
     //如果小尺寸显示模式，在显示搜索窗口的时候，左侧视图会被隐藏
     //如果点击一个搜索结果则隐藏搜索窗口，展示左侧视图
     if (!m_isNormalStateShow) {
-        //        CalendarGlobalEnv::getGlobalEnv()->registerKey("SearchItemEvent", "Keyboard");
-
         QVariant variant;
         CalendarGlobalEnv::getGlobalEnv()->getValueByKey("SearchItemEvent", variant);
         QString searchItemEvent = variant.toString();
@@ -623,9 +680,9 @@ void Calendarmainwindow::slotSearchSelectSchedule(const ScheduleDataInfo &schedu
     CScheduleBaseWidget *_showWidget = dynamic_cast<CScheduleBaseWidget *>(m_stackWidget->currentWidget());
     if (_showWidget) {
         //如果日程开始时间年份与选择时间年份不一样则切换年份显示
-        bool changeYear = _showWidget->getSelectDate().year() != scheduleInfo.getBeginDateTime().date().year();
+        bool changeYear = _showWidget->getSelectDate().year() != scheduleInfo->dtStart().date().year();
         //设置选择时间
-        if (_showWidget->setSelectDate(scheduleInfo.getBeginDateTime().date(), changeYear)) {
+        if (_showWidget->setSelectDate(scheduleInfo->dtStart().date(), changeYear)) {
             //更新显示数据
             _showWidget->updateData();
             //设置年份信息显示
@@ -733,9 +790,8 @@ void Calendarmainwindow::slotDeleteitem()
  * @brief Calendarmainwindow::slotSetMaxSize    根据屏幕分辨率调整窗口最大尺寸
  * @param size
  */
-void Calendarmainwindow::slotSetMaxSize(int size)
+void Calendarmainwindow::slotSetMaxSize()
 {
-    Q_UNUSED(size);
     //获取屏幕大小
     QSize deskSize = QApplication::desktop()->size();
     //设置最大尺寸为屏幕尺寸
@@ -753,6 +809,19 @@ void Calendarmainwindow::slotSearchFocusSwitch()
     }
 }
 
+void Calendarmainwindow::slotSidebarStatusChange(bool status)
+{
+    //先显示再调整窗口大小
+    m_sidebarView->setVisible(status);
+    if (status) {
+        //如果显示搜索窗口，若需要显示帐户列表则界面的最小尺寸需要984，否则为826
+        int minWidth = m_opensearchflag ? 984 : 826 ;
+        if (width() < minWidth) {
+            resize(minWidth, height());
+        }
+    }
+}
+
 void Calendarmainwindow::mouseMoveEvent(QMouseEvent *event)
 {
     //如果为平板模式则不可移动
@@ -774,8 +843,9 @@ void Calendarmainwindow::changeEvent(QEvent *event)
 
 void Calendarmainwindow::mousePressEvent(QMouseEvent *event)
 {
-    Q_UNUSED(event);
     setScheduleHide();
+    if (event->button() & Qt::LeftButton)
+        m_startPos = event->pos();
 }
 
 bool Calendarmainwindow::event(QEvent *event)
@@ -816,67 +886,87 @@ void Calendarmainwindow::slotapplicationStateChanged(Qt::ApplicationState state)
 
 void Calendarmainwindow::slotOpenSettingDialog()
 {
-    if (nullptr == m_dsdSetting) {
-        m_dsdSetting = new DSettingsDialog(this);
-        m_dsdSetting->setIcon(CDynamicIcon::getInstance()->getPixmap());
-        m_dsdSetting->setFixedSize(682, 506);
-        m_dsdSetting->widgetFactory()->registerWidget("JobTypeListView", [](QObject *obj) -> QWidget * {
-            if (DSettingsOption *option = qobject_cast<DSettingsOption *>(obj)) {
-                Q_UNUSED(option)
-                JobTypeListView *lv = new JobTypeListView();
-                lv->setObjectName("JobTypeListView");
-                return lv;
-            }
-            return nullptr;
-        });
-        QString strJson = QString(R"(
-                                  {"groups":[{"key":"setting_base","name":"Manage calendar","groups":[{"key":"event_types","name":"Event types","options":[{"key":"JobTypeListView","type":"JobTypeListView","name":"JobTypeListView","default":""}]}]}]}
-                                  )");
-
-        auto settings = Dtk::Core::DSettings::fromJson(strJson.toLatin1());
-        //settings->setBackend(&backend);
-        m_dsdSetting->setObjectName("SettingDialog");
-
-        m_dsdSetting->updateSettings(settings);
-        //恢复默认设置按钮不显示
-        m_dsdSetting->setResetVisible(false);
-
-        //QList<Widget>
-        QList<QWidget *> lstwidget = m_dsdSetting->findChildren<QWidget *>();
-        if (lstwidget.size() > 0) { //accessibleName
-            for (QWidget *wid : lstwidget) {
-                if ("ContentWidgetForsetting_base.event_types" == wid->accessibleName()) {
-                    JobTypeListView *view = m_dsdSetting->findChild<JobTypeListView *>("JobTypeListView");
-                    if (!view)
-                        return;
-                    DIconButton *addButton = new DIconButton(DStyle::SP_IncreaseElement, nullptr);
-                    //跟UI沟通size设置为20*20
-                    addButton->setFixedSize(20, 20);
-                    wid->layout()->addWidget(addButton);
-                    //使addButton的右边距等于view的右边距
-                    int leftMargin = wid->layout()->contentsMargins().left();
-                    wid->layout()->setContentsMargins(leftMargin, 0, leftMargin, 0);
-
-                    addButton->setEnabled(view->canAdd());
-
-                    //当日常类型超过上限时，更新button的状态
-                    connect(view, &JobTypeListView::signalAddStatusChanged, addButton, &DIconButton::setEnabled);
-                    //新增类型
-                    connect(addButton, &DIconButton::clicked, this, [=] {
-                        ScheduleTypeEditDlg a(m_dsdSetting);
-                        a.exec();
-                    });
-                }
-                if (wid->accessibleName().contains("DefaultWidgetAtContentRow")) {
-                    //DefaultWidgetAtContentRow是设置对话框右边每一个option条目对应widget的accessibleName的前缀，所以如果后续有更多条目，需要做修改
-                    wid->layout()->setMargin(0);
-                }
-            }
-        }
-    }
+    m_dsdSetting = new CSettingDialog(this);
     //内容定位到顶端
     m_dsdSetting->exec();
-    //使用晚后释放
+    //使用完后释放
     delete m_dsdSetting;
     m_dsdSetting = nullptr;
+    gCalendarManager->updateData();
+}
+
+void Calendarmainwindow::slotShowPrivacy()
+{
+    QString url = "";
+    QLocale locale;
+    QLocale::Country country = locale.country();
+    bool isCommunityEdition = DSysInfo::isCommunityEdition();
+    if (country == QLocale::China) {
+        if (isCommunityEdition) {
+            url = "https://www.deepin.org/zh/agreement/privacy/";
+        } else {
+            url = "https://www.uniontech.com/agreement/privacy-cn";
+        }
+    } else {
+        if (isCommunityEdition) {
+            url = "https://www.deepin.org/en/agreement/privacy/";
+        } else {
+            url = "https://www.uniontech.com/agreement/privacy-en";
+        }
+    }
+    QDesktopServices::openUrl(url);
+}
+
+void Calendarmainwindow::removeSyncToast()
+{
+    QWidget *content = this->window()->findChild<QWidget *>("_d_message_manager_content", Qt::FindDirectChildrenOnly);
+    if (nullptr == content) return;
+    for (DFloatingMessage *message : content->findChildren<DFloatingMessage *>(QString(), Qt::FindDirectChildrenOnly)) {
+        content->layout()->removeWidget(message);
+        message->hide();
+        message->deleteLater();
+    }
+}
+
+void Calendarmainwindow::slotShowSyncToast(int syncNum)
+{
+    //-1:正在刷新 0:正常 1:网络异常 2:服务器异常 3：存储已经满
+    static int preSyncNum = -2;
+    if (preSyncNum != syncNum && syncNum == -1) {
+        preSyncNum = -1;
+        //同步中
+        removeSyncToast();
+        DMessageManager::instance()->sendMessage(this->window(), QIcon::fromTheme(":/icons/deepin/builtin/icons/dde_calendar_spinner_32px.svg"), tr("Syncing..."));
+        return;
+    }
+    //
+    if (preSyncNum == -1 && syncNum != -1) {
+        preSyncNum = -2;
+        switch (syncNum) {
+        case 0: {
+            //同步成功
+            removeSyncToast();
+            DMessageManager::instance()->sendMessage(this->window(), QIcon::fromTheme(":/icons/deepin/builtin/icons/dde_calendar_success_200px.png"), tr("Sync successful"));
+            break;
+        }
+        case 1:
+        case 2:
+        case 3: {
+            //同步失败
+            removeSyncToast();
+            DMessageManager::instance()->sendMessage(this->window(), QIcon::fromTheme(":/icons/deepin/builtin/icons/dde_calendar_fail_200px.png"), tr("Sync failed, please try later"));
+            break;
+        }
+        default:
+            break;
+        }
+    }
+}
+
+void Calendarmainwindow::slotAccountUpdate()
+{
+    AccountItem::Ptr uidAccount = gUosAccountItem;
+    if (!uidAccount.isNull()) {
+        connect(uidAccount.get(), &AccountItem::signalSyncStateChange, this, &Calendarmainwindow::slotShowSyncToast);
+    }
 }
