@@ -1,44 +1,30 @@
-/*
- * Copyright (C) 2015 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     kirigaya <kirigaya@mkacg.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2015 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "todaybutton.h"
 #include "scheduledatamanage.h"
 #include "daymonthview.h"
 #include "constants.h"
 #include "dayhuangliview.h"
+#include "configsettings.h"
+#include "calendarglobalenv.h"
+#include "scheduledlg.h"
 
 #include <DPalette>
 #include <DHorizontalLine>
-#include <DHiDPIHelper>
+
 
 #include <QGridLayout>
-#include <QLabel>
 #include <QPainter>
 #include <QEvent>
 #include <QDebug>
 #include <QMessageBox>
 #include <QTime>
-#include <QQueue>
-#include <QSpacerItem>
 #include <QPainterPath>
 #include <QMouseEvent>
-#include <QtGlobal>
+#include <QApplication>
+
 
 DGUI_USE_NAMESPACE
 CDayMonthView::CDayMonthView(QWidget *parent)
@@ -65,6 +51,7 @@ void CDayMonthView::setShowDate(const QVector<QDate> &showDate, const QDate &sel
     m_currentDate = currentDate;
     m_dayMonthWidget->setShowDate(showDate, selectDate, currentDate);
     updateDateShow();
+    update();
 }
 
 void CDayMonthView::setLunarVisible(bool visible)
@@ -79,6 +66,7 @@ void CDayMonthView::setLunarVisible(bool visible)
 
 void CDayMonthView::setTheMe(int type)
 {
+    QColor todayColor = CScheduleDataManage::getScheduleDataManage()->getSystemActiveColor();
     m_dayMonthWidget->setTheMe(type);
     if (type == 0 || type == 1) {
         DPalette aniPa = this->palette();
@@ -88,22 +76,10 @@ void CDayMonthView::setTheMe(int type)
         setBackgroundRole(DPalette::Background);
         setBColor(tbColor);
 
-        DPalette todayPa = m_today->palette();
-        QColor todayColor = CScheduleDataManage::getScheduleDataManage()->getSystemActiveColor();
-        todayPa.setColor(DPalette::ButtonText, todayColor);
-        todayPa.setColor(DPalette::Dark, Qt::white);
-        todayPa.setColor(DPalette::Light, Qt::white);
-        QColor sbColor("#002A57");
-        sbColor.setAlphaF(0.05);
-        todayPa.setColor(DPalette::Shadow, sbColor);
-        m_today->setPalette(todayPa);
         QColor todayhover = "#000000";
         todayhover.setAlphaF(0.1);
         QColor todaypress = "#000000";
         todaypress.setAlphaF(0.2);
-        m_today->setBColor("#FFFFFF", todayhover, todaypress, "#FFFFFF", todayhover, todaypress);
-        m_today->setTColor(todayColor, "#001A2E", "#0081FF");
-        m_today->setshadowColor(sbColor);
         DPalette prevPalette = m_prevButton->palette();
         prevPalette.setColor(DPalette::Dark, QColor("#E6E6E6"));
         prevPalette.setColor(DPalette::Light, QColor("#E3E3E3"));
@@ -148,18 +124,6 @@ void CDayMonthView::setTheMe(int type)
         setBackgroundRole(DPalette::Background);
         setBColor(tbColor);
 
-        DPalette todayPa = m_today->palette();
-        QColor todayColor = CScheduleDataManage::getScheduleDataManage()->getSystemActiveColor();
-        todayPa.setColor(DPalette::ButtonText, todayColor);
-        todayPa.setColor(DPalette::Light, "#484848");
-        todayPa.setColor(DPalette::Dark, "#414141");
-        QColor sbColor("#000000");
-        sbColor.setAlphaF(0.05);
-        todayPa.setColor(DPalette::Shadow, sbColor);
-        m_today->setPalette(todayPa);
-        m_today->setBColor("#484848", "#727272", "#242424", "#414141", "#535353", "#282828");
-        m_today->setTColor(todayColor, "#FFFFFF", "#0081FF");
-        m_today->setshadowColor(sbColor);
         DPalette prevPalette = m_prevButton->palette();
         prevPalette.setColor(DPalette::Dark, QColor("#484848"));
         prevPalette.setColor(DPalette::Light, QColor("#414141"));
@@ -222,19 +186,10 @@ void CDayMonthView::initUI()
 {
     m_today = new CTodayButton;
     m_today->setText(QCoreApplication::translate("today", "Today", "Today"));
-    m_today->setFixedSize(100, DDEDayCalendar::D_MLabelHeight);
-    DPalette todayPa = m_today->palette();
-    QColor todayColor = CScheduleDataManage::getScheduleDataManage()->getSystemActiveColor();
-    todayPa.setColor(DPalette::ButtonText, todayColor);
-    todayPa.setColor(DPalette::Dark, Qt::white);
-    todayPa.setColor(DPalette::Light, Qt::white);
-    QColor sbColor("#002A57");
-    sbColor.setAlphaF(0.05);
-    todayPa.setColor(DPalette::Shadow, sbColor);
+    m_today->setFixedSize(80, DDEDayCalendar::D_MLabelHeight);
     QFont todayfont;
     todayfont.setPixelSize(DDECalendar::FontSizeFourteen);
     m_today->setFont(todayfont);
-    m_today->setPalette(todayPa);
     m_prevButton = new DIconButton(DStyle::SP_ArrowLeft, this);
     m_prevButton->setFixedSize(36, 36);
 
@@ -265,8 +220,12 @@ void CDayMonthView::initUI()
     m_upLayout->setSpacing(0);
     m_upLayout->setContentsMargins(22, 9, 0, 7);
     m_upLayout->addLayout(titleLayout);
+
+    m_weekWidget = new CWeekWidget();
+    m_weekWidget->setMaximumHeight(40);
     m_dayMonthWidget = new CDayMonthWidget();
-    m_upLayout->addWidget(m_dayMonthWidget);
+    m_upLayout->addWidget(m_weekWidget, 1);
+    m_upLayout->addWidget(m_dayMonthWidget, 6);
 
     //中间部分
     QVBoxLayout *midLayout = new QVBoxLayout;
@@ -308,28 +267,28 @@ void CDayMonthView::initUI()
     midLayout->addWidget(m_currentLuna);
 
     m_yiDownLayout = new QVBoxLayout;
-    m_yiDownLayout->setMargin(0);
     m_yiDownLayout->setSpacing(0);
     m_yiDownLayout->setContentsMargins(10, 5, 10, 0);
     hLabelF.setPixelSize(DDECalendar::FontSizeFourteen);
     m_yiLabel = new CDayHuangLiLabel(this);
     m_yiLabel->setbackgroundColor(QColor("#75C18E"));
     m_yiLabel->setTextInfo(QColor("#7B7B7B "), hLabelF);
-    m_yiLabel->setFixedSize(DDEDayCalendar::DHuangLiLabelWidth, DDEDayCalendar::DHuangLiLabelHeight);
+    m_yiLabel->setMinimumHeight(DDEDayCalendar::DHuangLiLabelHeight);
+    m_yiLabel->setMaximumHeight(DDEDayCalendar::DHuangLiLabelMaxHeight);
     m_yiLabel->setHuangLiText(QStringList());
-    m_yiDownLayout->addWidget(m_yiLabel);
+    m_yiDownLayout->addWidget(m_yiLabel, 1);
 
     m_jiDownLayout = new QVBoxLayout;
-    m_jiDownLayout->setMargin(0);
     m_jiDownLayout->setSpacing(0);
     m_jiDownLayout->setContentsMargins(10, 10, 10, 10);
 
     m_jiLabel = new CDayHuangLiLabel(this);
     m_jiLabel->setbackgroundColor(QColor("#C17575"));
     m_jiLabel->setTextInfo(QColor("#7B7B7B "), hLabelF);
-    m_jiLabel->setFixedSize(DDEDayCalendar::DHuangLiLabelWidth, DDEDayCalendar::DHuangLiLabelHeight);
+    m_jiLabel->setMinimumHeight(DDEDayCalendar::DHuangLiLabelHeight);
+    m_jiLabel->setMaximumHeight(DDEDayCalendar::DHuangLiLabelMaxHeight);
     m_jiLabel->setHuangLiText(QStringList(), 1);
-    m_jiDownLayout->addWidget(m_jiLabel);
+    m_jiDownLayout->addWidget(m_jiLabel, 1);
 
     m_hhLayout = new QVBoxLayout;
     m_hhLayout->setMargin(0);
@@ -338,15 +297,13 @@ void CDayMonthView::initUI()
     m_hhLayout->addLayout(midLayout);
 
     m_splitline = new DHorizontalLine;
+    m_splitline->setMinimumHeight(2);
 
-    m_splitline->setFixedSize(241, 2);
     QHBoxLayout *hlineLayout = new QHBoxLayout;
-    hlineLayout->setMargin(0);
     hlineLayout->setSpacing(0);
-    hlineLayout->setContentsMargins(0, 0, 0, 3);
-    hlineLayout->addStretch(1);
+    hlineLayout->setContentsMargins(50, 0, 50, 5);
     hlineLayout->addWidget(m_splitline);
-    hlineLayout->addStretch(1);
+
     m_hhLayout->addLayout(hlineLayout);
     m_hhLayout->addLayout(m_yiDownLayout);
     m_hhLayout->addLayout(m_jiDownLayout);
@@ -390,8 +347,8 @@ void CDayMonthView::updateDateLunarDay()
 {
     if (!m_huanglistate) return;
     m_currentLuna->setTextStr(m_huangLiInfo.mGanZhiYear + "年 " + "【" + m_huangLiInfo.mZodiac + "年】" + m_huangLiInfo.mGanZhiMonth + "月 " + m_huangLiInfo.mGanZhiDay + "日 ");
-    QStringList yiList = m_huangLiInfo.mSuit.split(".", QString::SkipEmptyParts);
-    QStringList jiList = m_huangLiInfo.mAvoid.split(".", QString::SkipEmptyParts);
+    QStringList yiList = m_huangLiInfo.mSuit.split(".", Qt::SkipEmptyParts);
+    QStringList jiList = m_huangLiInfo.mAvoid.split(".", Qt::SkipEmptyParts);
     m_yiLabel->setHuangLiText(yiList);
     m_jiLabel->setHuangLiText(jiList, 1);
 }
@@ -401,28 +358,6 @@ void CDayMonthView::changeSelectDate(const QDate &date)
     emit signalChangeSelectDate(date);
 }
 
-void CDayMonthView::resizeEvent(QResizeEvent *event)
-{
-    Q_UNUSED(event);
-    int leftMargin = qRound(width() * 0.0332 + 0.5);
-    int rightMargin = leftMargin;
-    int topMargin = qRound(height() * 0.0164 + 0.5);
-    int bottonMargin = topMargin;
-    m_upLayout->setContentsMargins(leftMargin, topMargin, rightMargin, bottonMargin);
-    m_splitline->setFixedWidth(qRound(0.6925 * width() + 0.5));
-
-    int hLeftMargin = qRound(width() * 0.026 + 0.5);
-    int hRightMargin = hLeftMargin;
-    int hTopMargin = qRound(height() * 0.01773 + 0.5);
-    int hBottonMargin = hTopMargin;
-    int lw = width() - hLeftMargin * 2;
-    int lh = qRound(height() * 0.0992);
-    m_yiLabel->setFixedSize(lw, lh);
-    m_yiDownLayout->setContentsMargins(hLeftMargin, qRound(hTopMargin * 0.5), hRightMargin, 0);
-    m_jiLabel->setFixedSize(lw, lh);
-    m_jiDownLayout->setContentsMargins(hLeftMargin, hTopMargin, hRightMargin, hBottonMargin);
-}
-
 void CDayMonthView::wheelEvent(QWheelEvent *event)
 {
     //如果是拖拽则退出
@@ -430,7 +365,7 @@ void CDayMonthView::wheelEvent(QWheelEvent *event)
     emit signalIsDragging(isDragging);
     if (isDragging)
         return;
-    if (event->delta() < 0) {
+    if (event->angleDelta().y() < 0) {
         //切换前一天
         changeSelectDate(m_selectDate.addDays(1));
     } else {
@@ -448,7 +383,7 @@ void CDayMonthView::paintEvent(QPaintEvent *e)
     QPainter painter(this);
     painter.setRenderHint(QPainter::Antialiasing); // 反锯齿;
     painter.save();
-    painter.setBrush(aniPa.background());
+    painter.setBrush(aniPa.window());
     painter.setPen(Qt::NoPen);
     QPainterPath painterPath;
     painterPath.moveTo(0, 0);
@@ -492,8 +427,8 @@ CDayMonthWidget::CDayMonthWidget(QWidget *parent)
     m_gridLayout->setMargin(0);
     m_gridLayout->setSpacing(0);
     m_dayNumFont.setPixelSize(DDECalendar::FontSizeTwelve);
-    for (int r = 0; r != 6; ++r) {
-        for (int c = 0; c != 7; ++c) {
+    for (int r = 0; r < 6; ++r) {
+        for (int c = 0; c < 7; ++c) {
             QWidget *cell = new QWidget;
             cell->installEventFilter(this);
             m_gridLayout->addWidget(cell, r, c, 1, 1);
@@ -557,7 +492,6 @@ const QDate CDayMonthWidget::getCellDate(int pos)
 void CDayMonthWidget::paintCell(QWidget *cell)
 {
     const QRect rect = cell->rect();
-
     const int pos = m_cellList.indexOf(cell);
     const bool isSelectedCell = pos == m_selectedCell;
     const bool isCurrentDay = getCellDate(pos) == m_currentDate;
@@ -612,21 +546,23 @@ void CDayMonthWidget::paintCell(QWidget *cell)
 
     if (m_vlineflag.count() == DDEDayCalendar::PainterCellNum) {
         if (m_vlineflag[pos]) {
-            painter.save();
-            QPen pen;
-            pen.setWidth(2);
-            pen.setColor(m_ceventColor);
-            painter.setPen(pen);
-            painter.setBrush(QBrush(m_ceventColor));
-            painter.setPen(Qt::NoPen);
-            int r = cell->width() * (4 / 25);
-            if (r < 4) {
-                r = 4;
-            } else if (r > 7) {
-                r = 7;
+            if (m_selectDate.month() == getCellDate(pos).month()) {
+                painter.save();
+                QPen pen;
+                pen.setWidth(2);
+                pen.setColor(m_ceventColor);
+                painter.setPen(pen);
+                painter.setBrush(QBrush(m_ceventColor));
+                painter.setPen(Qt::NoPen);
+                int r = int(cell->width() * 0.1);
+                if (r < 4) {
+                    r = 4;
+                } else if (r > 7) {
+                    r = 7;
+                }
+                painter.drawEllipse(cell->width() - r - 6, 4, r, r);
+                painter.restore();
             }
-            painter.drawEllipse(cell->width() - r - 6, 4, r, r);
-            painter.restore();
         }
     }
 }
@@ -645,10 +581,66 @@ bool CDayMonthWidget::eventFilter(QObject *o, QEvent *e)
         if (e->type() == QEvent::Paint) {
             paintCell(cell);
         } else if (e->type() == QEvent::MouseButtonPress) {
-            QMouseEvent *mouseEvent = dynamic_cast<QMouseEvent *>(e);
-            if (mouseEvent->button() == Qt::LeftButton) {
-                cellClicked(cell);
+            m_dayMouseState = 1;
+        } else if (e->type() == QEvent::MouseMove) {
+            if (m_dayMouseState == 1) {
+                m_dayMouseState = 2;
             }
+
+            if (2 == m_dayMouseState) {
+                QMouseEvent *mouseEvent = dynamic_cast<QMouseEvent *>(e);
+
+                //如果m_dayCreateState为0需要判断是否离开了选择区域，否则不需要判断
+                if (m_dayCreateState == 0 && !cell->rect().contains(mouseEvent->pos())) {
+                    //如果离开选择日期区域则修改鼠标显示
+                    setCursor(Qt::ClosedHandCursor);
+                    m_dayCreateState = 1;
+                }
+
+                if (m_dayCreateState != 0) {
+                    //根据是否在日历界面内设置鼠标形状和创建状态
+                    QPoint globalPoint =  QCursor::pos();
+                    QWidget *widget = QApplication::activeWindow();
+                    //
+                    if (widget != nullptr) {
+                        QRect rect = widget->geometry();
+
+                        if (rect.contains(globalPoint)) {
+                            setCursor(Qt::ClosedHandCursor);
+                            m_dayCreateState = 1;
+                        } else {
+                            setCursor(Qt::ForbiddenCursor);
+                            m_dayCreateState = 2;
+                        }
+                    }
+                }
+            }
+        } else if (e->type() == QEvent::MouseButtonRelease) {
+            QMouseEvent *mouseEvent = dynamic_cast<QMouseEvent *>(e);
+            //
+            if (m_dayCreateState == 1) {
+                //新建日程
+                const int pos = m_cellList.indexOf(cell);
+                QDate date = m_showDays.at(pos);
+                //设置日程开始时间
+                QDateTime _beginTime(date, QTime::currentTime());
+                //新建日程对话框
+                CScheduleDlg _scheduleDig(1, this, false);
+                //设置开始时间
+                _scheduleDig.setDate(_beginTime);
+                _scheduleDig.exec();
+
+            } else {
+                //如果不在点击区域内则不跳转日期
+                //跳转日期
+                if (mouseEvent->button() == Qt::LeftButton && cell->rect().contains(mouseEvent->pos())) {
+                    cellClicked(cell);
+                }
+            }
+
+            setCursor(Qt::ArrowCursor);
+            m_dayMouseState = 0;
+            m_dayCreateState = 0;
         }
     }
     return false;
@@ -715,6 +707,8 @@ void CDayMonthWidget::mousePressEvent(QMouseEvent *event)
 {
     QWidget::mousePressEvent(event);
     m_isFocus = false;
+    if (event->button() & Qt::LeftButton)
+        m_startPos = event->pos();
 }
 
 void CDayMonthWidget::cellClicked(QWidget *cell)
