@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #ifndef CALENDARPROGRAMEXITCONTROL_H
 #define CALENDARPROGRAMEXITCONTROL_H
 
@@ -24,12 +28,33 @@ public:
      * @brief reduce      接口处理结束后使用该函数，用来减少计数，跟addExc配对使用
      */
     void reduce();
+    static bool getClientIsOpen();
+    static void setClientIsOpen(bool clientIsOpen);
+
 private:
     CalendarProgramExitControl();
     void exit();
 private:
+    static bool m_clientIsOpen;
     int   m_excNum = 0;
     QReadWriteLock readWriteLock;
 };
 
+class DServiceExitControl
+{
+public:
+    DServiceExitControl()
+    {
+        CalendarProgramExitControl::getProgramExitControl()->addExc();
+    }
+    ~DServiceExitControl()
+    {
+        CalendarProgramExitControl::getProgramExitControl()->reduce();
+    }
+    void setClientIsOpen(bool isOpen)
+    {
+        CalendarProgramExitControl::setClientIsOpen(isOpen);
+    }
+};
+
 #endif // CALENDARPROGRAMEXITCONTROL_H
