@@ -1,23 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     uniontech  <uniontech@uniontech.com>
-*
-* Maintainer: uniontech  <chenhaifeng@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #ifndef GLOBALDEF_H
 #define GLOBALDEF_H
 
@@ -43,8 +27,8 @@
 #define TIMEFORMAT "hh:mm:ss"
 
 
-#define PROCESS_OPEN_CALENDAR "dbus-send --print-reply --dest=com.deepin.Calendar /com/deepin/Calendar com.deepin.Calendar.RaiseWindow"
-
+#define PROCESS_OPEN_CALENDAR_PROGRAM "dbus-send"
+#define PROCESS_OPEN_CALENDAR_ARGUMENTS "--print-reply --dest=com.deepin.Calendar /com/deepin/Calendar com.deepin.Calendar.RaiseWindow"
 //日程重复类型
 //每天
 #define DBUS_RRUL_EVED "FREQ=DAILY"
@@ -124,7 +108,7 @@
 //没有日程提醒回复语
 #define NO_SCHEDULE_TTS "您还没有日程提醒。"
 //删除重复日程询问回复语
-#define REPEST_SCHEDULE_CANCEL_TTS "该日程是循环的日程，请问是删除当前日程还是所有日程？"
+#define REPEST_SCHEDULE_CANCEL_TTS "该日程是循环的日程，请问是仅删除此日程还是删除全部？"
 //删除普通日程询问回复语
 #define CONFIRM_SCHEDULE_CANCEL_TTS "我要帮您取消这个日程吗？操作后将在日历中同步删除。"
 //删除选择日程回复语
