@@ -1,23 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     uniontech  <uniontech@uniontech.com>
-*
-* Maintainer: uniontech  <chenhaifeng@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "schedulestate.h"
 
 #include "../task/schedulebasetask.h"
@@ -25,16 +9,13 @@
 #include "../globaldef.h"
 #include "../state/queryschedulestate.h"
 
-scheduleState::scheduleState(CSchedulesDBus *dbus, scheduleBaseTask *task)
-    : m_dbus(dbus)
-    , m_Task(task)
+scheduleState::scheduleState(scheduleBaseTask *task)
+    : m_Task(task)
 {
 }
 
 scheduleState::~scheduleState()
 {
-    if (m_localData != nullptr)
-        delete m_localData;
 }
 
 Reply scheduleState::process(const JsonData *jsonData)
@@ -42,7 +23,7 @@ Reply scheduleState::process(const JsonData *jsonData)
     Reply reply;
     //如果时间无效
     if (jsonData->getDateTimeInvalid()) {
-        scheduleState *nextState = new queryScheduleState(m_dbus, m_Task);
+        scheduleState *nextState = new queryScheduleState(m_Task);
         setNextState(nextState);
         REPLY_ONLY_TTS(reply, DATETIME_ERR_TTS, DATETIME_ERR_TTS, true);
         return reply;
@@ -71,21 +52,12 @@ scheduleState *scheduleState::getNextState() const
     return m_nextState;
 }
 
-void scheduleState::setLocalData(CLocalData *localData)
+void scheduleState::setLocalData(const CLocalData::Ptr &localData)
 {
-    if (m_localData == localData) {
-        return;
-    }
-    if (m_localData != nullptr) {
-        delete m_localData;
-        m_localData = nullptr;
-    }
-    if (localData == nullptr)
-        return;
     m_localData = localData;
 }
 
-CLocalData *scheduleState::getLocalData() const
+CLocalData::Ptr scheduleState::getLocalData() const
 {
     return m_localData;
 }
