@@ -1,30 +1,16 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     uniontech  <uniontech@uniontech.com>
-*
-* Maintainer: uniontech  <chenhaifeng@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "selectandquerystate.h"
 #include "../globaldef.h"
+#include "commondef.h"
 #include "../task/schedulebasetask.h"
 #include "../data/changejsondata.h"
+#include <qloggingcategory.h>
 
-SelectAndQueryState::SelectAndQueryState(CSchedulesDBus *dbus, scheduleBaseTask *task)
-    : scheduleState(dbus, task)
+SelectAndQueryState::SelectAndQueryState(scheduleBaseTask *task)
+    : scheduleState(task)
 {
 }
 
@@ -40,14 +26,14 @@ scheduleState::Filter_Flag SelectAndQueryState::eventFilter(const JsonData *json
 {
     //如果语义包含全部关键字则为修改初始状态
     if (jsonData->getPropertyStatus() == JsonData::ALL
-    //如果语义包含下一个关键字则为修改初始状态
+        //如果语义包含下一个关键字则为修改初始状态
         || jsonData->getPropertyStatus() == JsonData::NEXT
         || jsonData->isVaild()
         //如果语义包含时间则为修改初始状态
-            || jsonData->getDateTime().suggestDatetime.size()>0
-           // 如果语义包含内容则为修改初始状态
-            || !jsonData->TitleName().isEmpty()
-            //如果语义包含重复类型则为修改初始状态
+        || jsonData->getDateTime().suggestDatetime.size() > 0
+        // 如果语义包含内容则为修改初始状态
+        || !jsonData->TitleName().isEmpty()
+        //如果语义包含重复类型则为修改初始状态
         || jsonData->getRepeatStatus() != JsonData::NONE) {
         return Filter_Flag::Fileter_Init;
     }
@@ -85,30 +71,30 @@ Reply SelectAndQueryState::normalEvent(const JsonData *jsonData)
     //获取第N个日程
     if (jsonData->getPropertyStatus() == JsonData::LAST) {
         offset = showcount;
-    }else {
+    } else {
         offset = jsonData->offset();
     }
-    if(offset > 0){
+    if (offset > 0) {
         m_localData->setOffset(offset);
         m_localData->setSelectInfo(m_localData->scheduleInfoVector().at(offset - 1));
-        ScheduleDtailInfo info = m_localData->SelectInfo();
+        DSchedule::Ptr info = m_localData->SelectInfo();
         //如果语义为“第xx个修改到xxx”，添加对修改信息的获取
         //类型转换
         JsonData *queryData = const_cast<JsonData *>(jsonData);
         changejsondata *mchangeJsonData = dynamic_cast<changejsondata *>(queryData);
         //如果有修改时间的信息则赋值
-        if(mchangeJsonData->toDateTime().suggestDatetime.size()>0){
+        if (mchangeJsonData->toDateTime().suggestDatetime.size() > 0) {
             m_localData->setToTime(mchangeJsonData->toDateTime());
         }
         //如果有修改内容的信息则获取
-        if(!mchangeJsonData->toPlaceStr().isEmpty()){
+        if (!mchangeJsonData->toPlaceStr().isEmpty()) {
             m_localData->setToTitleName(mchangeJsonData->toPlaceStr());
         }
         return m_Task->getReplyBySelectSchedule(m_localData->SelectInfo());
-    }else {
-        qDebug()<<"offset <=0";
+    } else {
+        qCWarning(CommonLogger) << "offset <=0";
         Reply reply;
-        REPLY_ONLY_TTS(reply,G_ERR_TTS,G_ERR_TTS,false);
+        REPLY_ONLY_TTS(reply, G_ERR_TTS, G_ERR_TTS, false);
         return reply;
     }
 }
