@@ -1,33 +1,17 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     uniontech  <uniontech@uniontech.com>
-*
-* Maintainer: uniontech  <chenhaifeng@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "icondframe.h"
 #include <QPainter>
 #include <QDate>
 #include <QSvgRenderer>
 #include <QVBoxLayout>
-
-#include <DApplicationHelper>
+#include <DGuiApplicationHelper>
 
 #include "../globaldef.h"
 #include "../interface/reply.h"
+#include <dguiapplicationhelper.h>
 
 IconDFrame::IconDFrame(QWidget *parent)
     : DFrame(parent)
@@ -65,7 +49,7 @@ void IconDFrame::setCenterLayout(QLayout *layout)
 
 void IconDFrame::paintEvent(QPaintEvent *event)
 {
-    setTheMe(DGuiApplicationHelper::instance()->themeType());
+    setTheMe(Dtk::Gui::DGuiApplicationHelper::instance()->themeType());
     DFrame::paintEvent(event);
     QPainter painter(this);
     painter.setRenderHint(QPainter::Antialiasing); // 反锯齿;
@@ -75,7 +59,7 @@ void IconDFrame::paintEvent(QPaintEvent *event)
         //设置边框为2
         pen.setWidth(2);
         //设置边框颜色为活动色
-        pen.setColor(DGuiApplicationHelper::instance()->applicationPalette().highlight().color());
+        pen.setColor(Dtk::Gui::DGuiApplicationHelper::instance()->applicationPalette().highlight().color());
         painter.setPen(pen);
         //设置边框矩形，由于插件widget会被助手覆盖一个像素，所以需要减去一个像素的外边
         QRect _showRect(1, 1, this->width() - 2, this->height() - 2);
