@@ -1,26 +1,10 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     uniontech  <uniontech@uniontech.com>
-*
-* Maintainer: uniontech  <chenhaifeng@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "itemwidget.h"
 
-#include <DApplicationHelper>
+#include <DGuiApplicationHelper>
 #include <QPainterPath>
 
 ItemWidget::ItemWidget(QWidget *parent)
@@ -36,7 +20,7 @@ ItemWidget::ItemWidget(QWidget *parent)
 
 void ItemWidget::paintEvent(QPaintEvent *event)
 {
-    setTheMe(DApplicationHelper::instance()->themeType());
+    setTheMe(DGuiApplicationHelper::instance()->themeType());
     DWidget::paintEvent(event);
     QPainter painter(this);
     painter.setRenderHint(QPainter::Antialiasing); // 反锯齿;
@@ -97,7 +81,6 @@ QColor ItemWidget::getBackgroundColor()
 
 void ItemWidget::setTheMe(const int type)
 {
-    m_scheduleColor.setTheMe(type);
     QColor titleColor;
     QColor datetimeColor;
     if (type == 0 || type == 1) {
@@ -119,18 +102,16 @@ void ItemWidget::setTheMe(const int type)
         m_BackgroundColor = "#FFFFFF";
         m_BackgroundColor.setAlphaF(0.05);
     }
-    //    DPalette palette;
-    //    setTitleColor(palette.color(DPalette::Normal, DPalette::BrightText));
     setTitleColor(titleColor);
     setDateTimeColor(datetimeColor);
 }
 
 QColor ItemWidget::ScheduleColor()
 {
-    return m_scheduleColor.getColorByTypeId(m_scheduleInfo.type.ID).splitColor;
+    return CScheduleDataManage::getScheduleDataManage()->getScheduleColorByType(m_scheduleInfo->scheduleTypeID()).orginalColor;
 }
 
-ScheduleDtailInfo ItemWidget::getScheduleInfo() const
+DSchedule::Ptr ItemWidget::getScheduleInfo() const
 {
     return m_scheduleInfo;
 }
@@ -150,18 +131,18 @@ void ItemWidget::setDateTimeColor(const QColor &DateTimeColor)
     m_DateTimeColor = DateTimeColor;
 }
 
-ScheduleDtailInfo ItemWidget::scheduleInfo() const
+DSchedule::Ptr ItemWidget::scheduleInfo() const
 {
     return m_scheduleInfo;
 }
 
-void ItemWidget::setScheduleInfo(const ScheduleDtailInfo &scheduleInfo)
+void ItemWidget::setScheduleInfo(const DSchedule::Ptr &scheduleInfo)
 {
     m_scheduleInfo = scheduleInfo;
-    setScheduleBeginTime(scheduleInfo.beginDateTime);
-    setScheduleEndTime(scheduleInfo.endDateTime);
-    setShowDate(scheduleInfo.beginDateTime.date());
-    setTitleContent(scheduleInfo.titleName);
+    setScheduleBeginTime(scheduleInfo->dtStart());
+    setScheduleEndTime(scheduleInfo->dtEnd());
+    setShowDate(scheduleInfo->dtStart().date());
+    setTitleContent(scheduleInfo->summary());
 }
 
 void ItemWidget::setTitleColor(const QColor &TitleColor)
