@@ -1,23 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     uniontech  <uniontech@uniontech.com>
-*
-* Maintainer: uniontech  <chenhaifeng@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "modifyscheduleitem.h"
 
 #include "../globaldef.h"
@@ -105,7 +89,7 @@ void modifyScheduleItem::drawTime(QPainter &painter)
     painter.setPen(getDateTimeColor());
     painter.setFont(getDateTimeFont());
     QString timestr;
-    if (scheduleInfo().allday) {
+    if (scheduleInfo()->allDay()) {
         timestr = ALL_DAY;
     } else {
         timestr = QString("%1-%2").arg(getScheduleBeginTime().toString("hh:mm")).arg(getScheduleEndTime().toString("hh:mm"));
