@@ -1,29 +1,13 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     chenhaifeng  <chenhaifeng@uniontech.com>
-*
-* Maintainer: chenhaifeng  <chenhaifeng@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #ifndef CREATSHCEDULEITEM_H
 #define CREATSHCEDULEITEM_H
 
 #include "itemwidget.h"
-#include "../data/schedulestructs.h"
-#include "../data/schedulecolourmanage.h"
+#include "dschedule.h"
+
 #include <QVBoxLayout>
 
 class scheduleitemdate;
@@ -35,17 +19,17 @@ public:
     explicit scheduleitemwidget(QWidget *parent = nullptr);
     ~scheduleitemwidget();
 
-    void setScheduleDtailInfo(QVector<ScheduleDtailInfo> &scheduleInfo);
+    void setScheduleDtailInfo(const DSchedule::List &scheduleInfo);
     void addscheduleitem();
 signals:
-    void signalItemPress(const ScheduleDtailInfo &info);
+    void signalItemPress(const DSchedule::Ptr &info);
 
 private:
     void sortScheduleWithTime();
 
 private:
-    ScheduleDtailInfo m_scheduleDtailInfo;
-    QVector<ScheduleDtailInfo> m_scheduleInfo;
+    DSchedule::Ptr m_scheduleDtailInfo;
+    DSchedule::List m_scheduleInfo;
 };
 
 class scheduleitem : public ItemWidget
@@ -63,7 +47,7 @@ private:
 protected:
     void mousePressEvent(QMouseEvent *event) override;
 signals:
-    void signalItemPress(const ScheduleDtailInfo &info);
+    void signalItemPress(const DSchedule::Ptr &info);
 
 private:
     const int m_timeLeftMargin = 13;
@@ -80,7 +64,7 @@ class scheduleitemdate : public QWidget
     Q_OBJECT
 public:
     explicit scheduleitemdate(QWidget *parent = nullptr);
-    void setScheduleDtailInfo(ScheduleDtailInfo &scheduelDtailInfo);
+    void setScheduleDtailInfo(const DSchedule::Ptr &scheduelDtailInfo);
 
     QColor DetailsColor();
 
@@ -88,7 +72,7 @@ protected:
     void paintEvent(QPaintEvent *event);
 
 private:
-    ScheduleDtailInfo m_scheduleDtailInfo;
+    DSchedule::Ptr m_scheduleDtailInfo;
     QColor m_DateTimeColor;
 
     const int m_LeftMargin = 13;
